## -*-cperl-*-
## Filename: UCS/SFunc.pm
## Modified: Wed Aug 17 23:47:56 2005 (severt)   
##   Author: Stefan Evert
##  Purpose: special functions and statistical distributions

package UCS::SFunc;

use base qw<Exporter>;
@EXPORT = (
	   # special functions (binomial coefficient, Gamma, Beta)
	   qw<choose lchoose>,
	   qw<gamma  lgamma  igamma ligamma rgamma lrgamma igamma_inv  ligamma_inv rgamma_inv  lrgamma_inv>,
	   qw<beta   lbeta   ibeta  libeta  rbeta  lrbeta  ibeta_inv   libeta_inv  rbeta_inv   lrbeta_inv>,
	   # statistical distributions (binomial, Poisson, normal, chi-squared, hypergeometric)
	   qw<dbinom ldbinom pbinom lpbinom qbinom lqbinom>,
	   qw<dpois  ldpois  ppois  lppois  qpois  lqpois>,
	   qw<dnorm  ldnorm  pnorm  lpnorm  qnorm  lqnorm>,
	   qw<dchisq ldchisq pchisq lpchisq qchisq lqchisq>,
	   qw<dhyper ldhyper phyper lphyper>,
	   );

use UCS;
use UCS::R;
use UCS::Expression::Func;


##
##  SPECIAL FUNCTIONS
##

# $coef = choose($n, $k);
# $log_coef = lchoose($n, $k);
# the binomial coefficient and its logarithm
sub choose ( $$ ) {
  return &UCS::R::choose(@_);
}
sub lchoose ( $$ ) {
  return &UCS::R::lchoose(@_);
}

# $g = gamma($a);
# $log_g = lgamma($a);
# the Gamma function and its logarithm
sub gamma ( $ ) {
  return &UCS::R::gamma(@_);
}
sub lgamma ( $ ) {
  return &UCS::R::lgamma(@_);
}

# $y = igamma($a, $x [, $upper]);
# $y = rgamma($a, $x [, $upper]);
# $log_y = ligamma($a, $x [, $upper]);
# $log_y = lrgamma($a, $x [, $upper]);
# the incomplete and regularised Gamma functions (lower and upper), as well as their logarithms
sub igamma ( $$;$ ) {
  return &UCS::R::igamma(@_);
}
sub rgamma ( $$;$ ) {
  return &UCS::R::rgamma(@_);
}
sub ligamma ( $$;$ ) {
  return &UCS::R::ligamma(@_);
}
sub lrgamma ( $$;$ ) {
  return &UCS::R::lrgamma(@_);
}

# $x = igamma_inv($a, $y [, $upper]);
# $x = rgamma_inv($a, $y [, $upper]);
# $x = ligamma_inv($a, $log_y [, $upper]);
# $x = lrgamma_inv($a, $log_y [, $upper]);
# inverse of the incomplete and regularised Gamma functions (and their logarithms)
sub igamma_inv ( $$;$ ) {
  return &UCS::R::igamma_inv(@_);
}
sub rgamma_inv ( $$;$ ) {
  return &UCS::R::rgamma_inv(@_);
}
sub ligamma_inv ( $$;$ ) {
  return &UCS::R::ligamma_inv(@_);
}
sub lrgamma_inv ( $$;$ ) {
  return &UCS::R::lrgamma_inv(@_);
}

# $b = beta($a, $b);
# $log_b = lbeta($a, $b);
# the Beta function and its logarithm
sub beta ( $ ) {
  return &UCS::R::beta(@_);
}
sub lbeta ( $ ) {
  return &UCS::R::lbeta(@_);
}


# $y = ibeta($x, $a, $b);
# $y = rbeta($x, $a, $b);
# $log_y = libeta($x, $a, $b);
# $log_y = lrbeta($x, $a, $b);
# the incomplete and regularised Beta functions and their logarithms
sub ibeta ( $$$ ) {
  return &UCS::R::ibeta(@_);
}
sub rbeta ( $$$ ) {
  return &UCS::R::rbeta(@_);
}
sub libeta ( $$$ ) {
  return &UCS::R::libeta(@_);
}
sub lrbeta ( $$$ ) {
  return &UCS::R::lrbeta(@_);
}

# $x = ibeta_inv($y, $a, $b);
# $x = rbeta_inv($y, $a, $b);
# $x = libeta_inv($log_y, $a, $b);
# $x = lrbeta_inv($log_y, $a, $b);
# inverse of incomplete and regularised Beta functions (and their logarithms)
sub ibeta_inv ( $$$ ) {
  return &UCS::R::ibeta_inv(@_);
}
sub rbeta_inv ( $$$ ) {
  return &UCS::R::rbeta_inv(@_);
}
sub libeta_inv ( $$$ ) {
  return &UCS::R::libeta_inv(@_);
}
sub lrbeta_inv ( $$$ ) {
  return &UCS::R::lrbeta_inv(@_);
}


##
##  STATISTICAL DISTRIBUTIONS
##

# $d = dbinom($k, $size, $prob);
# $ld = ldbinom($k, $size, $prob);
# $p = pbinom($k, $size, $prob [, $upper]);
# $lp = lpbinom($k, $size, $prob [, $upper]);
# $k = qbinom($p, $size, $prob [, $upper]);
# $k = lqbinom($lp, $size, $prob [, $upper]);
# density, tail probabilities, and quantiles of binomial distribution (incl. logarithmic versions)
sub dbinom ( $$$ ) {
  return &UCS::R::dbinom(@_);
}
sub ldbinom ( $$$ ) {
  return &UCS::R::ldbinom(@_);
}

sub pbinom ( $$$;$ ) {
  return &UCS::R::pbinom(@_);
}
sub lpbinom ( $$$;$ ) {
  return &UCS::R::lpbinom(@_);
}

sub qbinom ( $$$;$ ) {
  return &UCS::R::qbinom(@_);
}
sub lqbinom ( $$$;$ ) {
  return &UCS::R::lqbinom(@_);
}

# $d = dpois($k, $lambda);
# $ld = ldpois($k, $lambda);
# $p = ppois($k, $lambda [, $upper]);
# $lp = lppois($k, $lambda [, $upper]);
# $k = qpois($p, $lambda [, $upper]);
# $k = lqpois($lp, $lambda [, $upper]);
# density, tail probabilities, and quantiles of Poisson distribution (incl. logarithmic versions)
sub dpois ( $$ ) {
  return &UCS::R::dpois(@_);
}
sub ldpois ( $$ ) {
  return &UCS::R::ldpois(@_);
}

sub ppois ( $$;$ ) {
  return &UCS::R::ppois(@_);
}
sub lppois ( $$;$ ) {
  return &UCS::R::lppois(@_);
}

sub qpois ( $$;$ ) {
  return &UCS::R::qpois(@_);
}
sub lqpois ( $$;$ ) {
  return &UCS::R::lqpois(@_);
}

# $d = dnorm($x, $mu, $sigma);
# $ld = ldnorm($x, $mu, $sigma);
# $p = pnorm($x, $mu, $sigma [, $upper]);
# $lp = lpnorm($x, $mu, $sigma [, $upper]);
# $x = qnorm($p, $mu, $sigma [, $upper]);
# $x = lqnorm($lp, $mu, $sigma [, $upper]);
# density, tail probabilities, and quantiles of normal distribution (incl. logarithmic versions)
sub dnorm ( $;$$ ) {
  return &UCS::R::dnorm(@_);
}
sub ldnorm ( $;$$ ) {
  return &UCS::R::ldnorm(@_);
}

sub pnorm ( $;$$$ ) {
  return &UCS::R::pnorm(@_);
}
sub lpnorm ( $;$$$ ) {
  return &UCS::R::lpnorm(@_);
}

sub qnorm ( $;$$$ ) {
  return &UCS::R::qnorm(@_);
}
sub lqnorm ( $;$$$ ) {
  return &UCS::R::lqnorm(@_);
}

# $d = dchisq($x, $df);
# $ld = ldchisq($x, $df);
# $p = pchisq($x, $df [, $upper]);
# $lp = lpchisq($x, $df [, $upper]);
# $x = qchisq($p, $df [, $upper]);
# $x = lqchisq($lp, $df [, $upper]);
# density, tail probabilities, and quantiles of chi-squared distribution
sub dchisq ( $$ ) {
  return &UCS::R::dchisq(@_);
}
sub ldchisq ( $$ ) {
  return &UCS::R::ldchisq(@_);
}

sub pchisq ( $$;$ ) {
  return &UCS::R::pchisq(@_);
}
sub lpchisq ( $$;$ ) {
  return &UCS::R::lpchisq(@_);
}

sub qchisq ( $$;$ ) {
  return &UCS::R::qchisq(@_);
}
sub lqchisq ( $$;$ ) {
  return &UCS::R::lqchisq(@_);
}

# $d = dhyper($k, $R1, $R2, $C1, $C2);
# $ld = ldhyper($k, $R1, $R2, $C1, $C2);
# $p = phyper($k, $R1, $R2, $C1, $C2 [, $upper]);
# $lp = lphyper($k, $R1, $R2, $C1, $C2 [, $upper]);
# density and tail probabilities of hypergeometric distribution, using a mixed implementation for improved accuracy
sub dhyper ( $$$$$ ) {
  return &UCS::R::dhyper(@_);
}
sub ldhyper ( $$$$$ ) {
  return &UCS::R::ldhyper(@_);
}

sub phyper ( $$$$$;$ ) {
  return &UCS::R::phyper(@_);
}
sub lphyper ( $$$$$;$ ) {
  return &UCS::R::lphyper(@_);
}


1;



__END__


=head1 NAME

UCS::SFunc - Special functions and statistical distributions

=head1 SYNOPSIS

  use UCS::SFunc;

  # special functions (all logarithms are base 10)
  $c     = choose($n, $k);	 # binomial coefficient
  $log_c = lchoose($n, $k); 

  $y     = gamma($a);	         # Gamma function 
  $log_y = lgamma($a);
  $y     = igamma($a, $x [, $upper]);  # incomplete Gamma functions
  $log_y = ligamma($a, $x [, $upper]);
  $y     = rgamma($a, $x [, $upper]);  # regularised Gamma functions
  $log_y = lrgamma($a, $x [, $upper]);
  $x     = igamma_inv($a, $y [, $upper]); # inverse Gamma functions
  $x     = ligamma_inv($a, $log_y [, $upper]);
  $x     = rgamma_inv($a, $y [, $upper]); 
  $x     = lrgamma_inv($a, $log_y [, $upper]);

  $y     = beta($a, $b);         # Beta function
  $log_y = lbeta($a, $b);
  $y     = ibeta($x, $a, $b);	 # incomplete Beta function
  $log_y = libeta($x, $a, $b);
  $y     = rbeta($x, $a, $b);	 # regularised Beta function
  $log_y = lrbeta($x, $a, $b);
  $x     = ibeta_inv($y, $a, $b);	 # inverse Beta functions
  $x     = libeta_inv($log_y, $a, $b);
  $x     = rbeta_inv($y, $a, $b);
  $x     = lrbeta_inv($log_y, $a, $b);


  # binomial distribution (density, tail probabilities, quantiles)
  $d  = dbinom($k, $size, $prob);
  $ld = ldbinom($k, $size, $prob);
  $p  = pbinom($k, $size, $prob [, $upper]);
  $lp = lpbinom($k, $size, $prob [, $upper]);
  $k  = qbinom($p, $size, $prob [, $upper]);
  $k  = lqbinom($lp, $size, $prob [, $upper]);

  # Poisson distribution (density, tail probabilities, quantiles)
  $d  = dpois($k, $lambda);
  $ld = ldpois($k, $lambda);
  $p  = ppois($k, $lambda [, $upper]);
  $lp = lppois($k, $lambda [, $upper]);
  $k  = qpois($p, $lambda [, $upper]);
  $k  = lqpois($lp, $lambda [, $upper]);

  # normal distribution (density, tail probabilities, quantiles)
  $d  = dnorm($x, $mu, $sigma);
  $ld = ldnorm($x, $mu, $sigma);
  $p  = pnorm($x, $mu, $sigma [, $upper]);
  $lp = lpnorm($x, $mu, $sigma [, $upper]);
  $x  = qnorm($p, $mu, $sigma [, $upper]);
  $x  = lqnorm($lp, $mu, $sigma [, $upper]);

  # chi-squared distribution (density, tail probabilities, quantiles)
  $d  = dchisq($x, $df);
  $ld = ldchisq($x, $df);
  $p  = pchisq($x, $df [, $upper]);
  $lp = lpchisq($x, $df [, $upper]);
  $x  = qchisq($p, $df [, $upper]);
  $x  = lqchisq($lp, $df [, $upper]);

  # hypergeometric distribution (density and tail probabilities)
  $d = dhyper($k, $R1, $R2, $C1, $C2);
  $ld = ldhyper($k, $R1, $R2, $C1, $C2);
  $p = phyper($k, $R1, $R2, $C1, $C2 [, $upper]);
  $lp = lphyper($k, $R1, $R2, $C1, $C2 [, $upper]);


=head1 DESCRIPTION

This module provides B<special functions> and common B<statistical
distributions>.  Currently, all functions are imported from the B<UCS/R>
system (using the B<UCS::R> interface).


=head1 SPECIAL FUNCTIONS

B<UCS::SFunc> currently provides the following special mathematical functions:
B<binomial coefficients>, the B<Gamma function>, the B<incomplete Gamma
functions> and their inverses, the B<regularised Gamma functions> and their
inverses, the B<Beta function>, the B<incomplete Beta function> and its
inverse, and the B<regularised Beta function> and its inverse. Note that
all logarithmic versions return B<base 10> logarithms!

=over 4

=item $coef = choose($n, $k);

=item $log_coef = lchoose($n, $k);

The B<binomial coefficient> "I<$n> over I<$k>", and its logarithm.

=item $y = gamma($a);

=item $log_y = lgamma($a);

The (complete) B<Gamma function> with argument I<$a>, and its logarithm.
Note that the factorial I<n!> is equal to C<gamma(I<n>+1)>. 

=item $y = igamma($a, $x [, $upper]);

=item $log_y = ligamma($a, $x [, $upper]);

The B<incomplete Gamma function> with arguments I<$a> and I<$x>, and its
logarithm.  If I<$upper> is specified and true, the upper incomplete Gamma
function is computed, otherwise the lower incomplete Gamma function.  It is
recommended to set I<$upper> to the string constant C<'upper'> as a reminder
of its function.

=item $x = igamma_inv($a, $y [, $upper]);

=item $x = ligamma_inv($a, $log_y [, $upper]);

The B<inverse> of the B<incomplete Gamma function>, as well as the inverse of its logarithm. 

=item $y = rgamma($a, $x [, $upper]);

=item $log_y = lrgamma($a, $x [, $upper]);

The B<regularised Gamma function> with arguments I<$a> and I<$x>, and its
logarithm.  If I<$upper> is specified and true, the upper regularised Gamma
function is computed, otherwise the lower regularised Gamma function.  It is
recommended to set I<$upper> to the string constant C<'upper'> as a reminder
of its function.

=item $x = rgamma_inv($a, $y [, $upper]);

=item $x = lrgamma_inv($a, $log_y [, $upper]);

The B<inverse> of the B<regularised Gamma function>, as well as the inverse of its logarithm. 

=item $beta = beta($a, $b);

=item $log_beta = lbeta($a, $b);

The (complete) B<Beta function> with arguments I<$a> and I<$b>, and
its logarithm.

=item $y = ibeta($x, $a, $b);

=item $log_y = libeta($x, $a, $b);

The B<incomplete Beta function> with arguments I<$x>, I<$a>, and I<$b>, and its
logarithm.  

=item $x = ibeta_inv($y, $a, $b);

=item $x = libeta_inv($log_y, $a, $b);

The B<inverse> of the B<incomplete Beta function>, as well as the inverse of
its logarithm.

=item $y = rbeta($x, $a, $b);

=item $log_y = lrbeta($x, $a, $b);

The B<regularised Beta function> with arguments I<$x>, I<$a>, and I<$b>, and
its logarithm.

=item $x = rbeta_inv($y, $a, $b);

=item $x = lrbeta_inv($log_y, $a, $b);

The B<inverse> of the B<regularised Beta function>, as well as the inverse of
its logarithm.

=back



=head1 STATISTICAL DISTRIBUTIONS

B<UCS::SFunc> computes B<densities>, B<tail probabilities> (= distribution
function), and B<quantiles> for the following statistical distributions:
B<binomial> distribution, B<Poisson> distribution, B<normal> distribution,
B<chi-squared> distribution, B<hypergeometric> distribution.  The function
names are the common abbreviations as used e.g. in the B<R> language, with
additional logarithmic versions (that start with the letter C<l>) (these
correspond to the C<log=TRUE> and C<log.p=TRUE> parameters in R).

Note that logarithmic probabilities are always given as B<negative
base 10> logarithms.  The logarithmic density and tail probability
functions return such logarithmic p-values, and the quantile functions
expect them in their first argument.


=head2 The Binomial Distribution

Binomial distribution with parameters I<$size> (= number of trials)
and I<$prob> (= success probability in single trial).  I<< E[X] =
$size * $prob >>, I<< V[X] = $size * $prob * (1 - $prob) >>.

=over 4

=item $d = dbinom($k, $size, $prob);

=item $ld = ldbinom($k, $size, $prob);

Density I<P(X = $k)> and its negative base 10 logarithm.

=item $p = pbinom($k, $size, $prob [, $upper]);

=item $lp = lpbinom($k, $size, $prob [, $upper]);

Tail probabilities I<< P(X <= $k) >> and I<< P(X > $k) >> (if
I<$upper> is specified and true), and their negative base 10
logarithms.  It is recommended to set I<$upper> to the string
C<'upper'> as a reminder of its meaning.

The R implementation of binomial tail probabilities underflows for very small
probabilities (even in the logarithmic version), as of R version 2.1.
Therefore, these functions use a mixture of R and Perl code to compute upper
tail probabilities for large samples (which are most likely to lead to
undeflow problems for cooccurrence data).

=item $k = qbinom($p, $size, $prob [, $upper]);

=item $k = lqbinom($lp, $size, $prob [, $upper]);

Lower and upper quantiles.  The lower quantile is the smallest value
I<$k> with I<< P(X <= $k) >= $p >>.  The upper quantile (which is
computed when I<$upper> is specified and true) is the largest value
I<$k> with I<< P(X > $k) >= $p >>.  In the logarithmic version, I<$lp>
must be the negative base 10 logarithm of the desired p-value.

Note that these functions use the R implementation directly without a
workaround for undeflow problems.  The quantiles returned for very small
p-values (especially when using B<lqbinom>) are therefore unreliable and
should be used with caution.

=back


=head2 The Poisson Distribution

Poisson distribution with parameter I<$lambda> (= expectation);
I<< E[X] = V[X] = $lambda >>.

=over 4

=item $d = dpois($k, $lambda);

=item $ld = ldpois($k, $lambda);

Density I<P(X = $k)> and its negative base 10 logarithm.

=item $p = ppois($k, $lambda [, $upper]);

=item $lp = lppois($k, $lambda [, $upper]);

Tail probabilities I<< P(X <= $k) >> and I<< P(X > $k) >> (if
I<$upper> is specified and true), and their negative base 10
logarithms.  It is recommended to set I<$upper> to the string
C<'upper'> as a reminder of its meaning.

=item $k = qpois($p, $lambda [, $upper]);

=item $k = lqpois($lp, $lambda [, $upper]);

Lower and upper quantiles.  The lower quantile is the smallest value
I<$k> with I<< P(X <= $k) >= $p >>.  The upper quantile (which is
computed when I<$upper> is specified and true) is the largest value
I<$k> with I<< P(X > $k) >= $p >>.  In the logarithmic version, I<$lp>
must be the negative base 10 logarithm of the desired p-value.

=back


=head2 The Normal Distribution

Normal distribution with parameters I<$mu> (= expectation) and
I<$sigma> (= standard deviation).  Unspecified parameters default to
I<$mu = 0> and I<$sigma = 1>. I<< E[X] = $mu >>, I<< V[X] = $sigma **
2 >>.

=over 4

=item $d = dnorm($x, $mu, $sigma);

=item $ld = ldnorm($x, $mu, $sigma);

Density I<P(X = $x)> and its negative base 10 logarithm.

=item $p = pnorm($x, $mu, $sigma [, $upper]);

=item $lp = lpnorm($x, $mu, $sigma [, $upper]);

Tail probabilities I<< P(X <= $x) >> and I<< P(X >= $x) >> (if
I<$upper> is specified and true), and their negative base 10
logarithms.  It is recommended to set I<$upper> to the string
C<'upper'> as a reminder of its meaning.

=item $x = qnorm($p, $mu, $sigma [, $upper]);

=item $x = lqnorm($lp, $mu, $sigma [, $upper]);

Lower and upper quantiles.  The lower quantile is the smallest value
I<$x> with I<< P(X <= $x) >= $p >>.  The upper quantile (which is
computed when I<$upper> is specified and true) is the largest value
I<$x> with I<< P(X >= $x) >= $p >>.  In the logarithmic version, I<$lp>
must be the negative base 10 logarithm of the desired p-value.

=back


=head2 The Chi-Squared Distribution

Chi-squared distribution with parameter I<$df> (= degrees of freedom);
I<< E[X] = $df >>, I<< V[X] = 2 * $df >>.

=over 4

=item $d = dchisq($x, $df);

=item $ld = ldchisq($x, $df);

Density function I<f(x)> and its negative base 10 logarithm.

=item  $p  = pchisq($x, $df [, $upper]);

=item  $lp = lpchisq($x, $df [, $upper]);

Tail probabilities I<< P(X <= $x) >> and I<< P(X >= $x) >> (if
I<$upper> is specified and true), and their negative base 10
logarithms.  It is recommended to set I<$upper> to the string
C<'upper'> as a reminder of its meaning.

=item  $x  = qchisq($p, $df [, $upper]);

=item  $x  = lqchisq($lp, $df [, $upper]);

Lower and upper quantiles.  The lower quantile is the smallest value
I<$x> with I<< P(X <= $x) >= $p >>.  The upper quantile (which is
computed when I<$upper> is specified and true) is the largest value
I<$x> with I<< P(X >= $x) >= $p >>.  In the logarithmic version,
I<$lp> must be the negative base 10 logarithm of the desired p-value.

=back


=head2 The Hypergeometric Distribution

Hypergeometric distribution of the upper left-hand corner I<X> in a
2x2 contingency table with fixed marginals I<$R1>, I<$R2>, I<$C1>, and
I<$C2>, where both I<< $R1 + $R2 >> and I<< $C1 + $C2 >> must sum to
the sample size I<N>.  I<$k> represents the observed value of I<X> and
must be in the admissible range I<< max(0, $R1 - $C2) <= $k <=
min($R1, $C1) >>, otherwise the density will be given as 0 and tail
probabilities as 1 or 0, respectively.  I<< E[X] = $R1 * $C1 / $N >>,
I<< V[X] = $R1 * $R2 * $C1 * $C2 / (N^2 * (N-1)) >>.

For R versions before 2.0, the upper tail probabilities are computed with a
mixture of R and Perl code to circumvent a cancellation problem in the R
implementation and achieve better precision.  For this reason, the functions
for quantiles are currently not supported (but may be when R version 2.0 is 
required for the UCS toolkit).

=over 4

=item $d = dhyper($k, $R1, $R2, $C1, $C2);

=item $ld = ldhyper($k, $R1, $R2, $C1, $C2);

Density I<< P(X = $k) >> and its negative base 10 logarithm.

=item $p = phyper($k, $R1, $R2, $C1, $C2 [, $upper]);

=item $lp = lphyper($k, $R1, $R2, $C1, $C2 [, $upper]);

Tail probabilities I<< P(X <= $k) >> and I<< P(X > $k) >> (if
I<$upper> is specified and true), and their negative base 10
logarithms.  It is recommended to set I<$upper> to the string
C<'upper'> as a reminder of its meaning.

=back


=head1 COPYRIGHT

Copyright 2004-2005 Stefan Evert.

This software is provided AS IS and the author makes no warranty as to
its use and performance. You may use the software, redistribute and
modify it under the same terms as Perl itself.

=cut








