##
##  UCS / The R ToolBox
##

## Filename: ucs.R
## Modified: Sat Aug 20 02:13:05 2005 (severt)   
##   Author: Stefan Evert
##  Purpose: UCS configuration and loader routines

ucs.basedir <- '/usr/share/perl-UCS'	 # in-place edit by Install.perl
ucs.dataset.dir <- '/usr/share/perl-UCS/DataSet'	 # in-place edit by Install.perl
ucs.rootdir <- '/'	 # in-place edit by Install.perl
ucs.cygwin <- FALSE	 # in-place edit by Install.perl
ucs.version <- '0.5'	 # in-place edit by Install.perl
ucs.R.dir <- paste(ucs.basedir, "R", sep="/")
ucs.R.lib <- paste(ucs.R.dir, "lib", sep="/")
ucs.cygwin.bash <- paste(ucs.rootdir, "bin", "bash.exe", sep="/")
ucs.cygwin.tmpdir <- paste(ucs.rootdir, "tmp", sep="/")

## load UCS library stub to make on-line documentation available
.libPaths(c(.libPaths(),paste(ucs.R.dir, "library", sep="/"))) # add UCS/R library tree to search path
library("UCS")                          # load UCS/R library stub, making documentation available

## list of loaded libraries (to avoid unnecessary reloading of internal prerequisites)
.ucs.loaded <- list()

## load UCS/R library (from UCS/R lib directory)
##   ucs.library(name)
## name = name of library (without extension, e.g. "plots")
## NB libraries may be re-loaded by calling ucs.library() with reload=TRUE;
## NB by default UCS/R checks whether a requested library has already been loaded
##   ucs.library(all=TRUE)
## loads all available UCS/R libraries (see below for listing)
##   ucs.library()
## lists available UCS/R libraries with short description; returns a list with the
## library names as keys; the list is blessed into class UCSLibList (for display)
ucs.library <- function (name, all=FALSE, reload=FALSE) {
  libs <- list(base="AM registry and some basic functions for UCS data sets",
               plots="graphs for the evaluation of association measures",
               iaa="measuring inter-annotator agreement",
               sfunc="some special functions (gamma, beta, confidence intervals)",
               gam="generalised association measures (GAM)",
               eo="visualisation of GAMs and data sets in the (e,o) plane",
               lexstats="utility functions and graphs for lexical statistics",
               zm="the Zipf-Mandelbrot LNRE model",
               fzm="the finite Zipf-Mandelbrot LNRE model")
  if (all) {
    for (lib.name in names(libs)) ucs.library(name=lib.name, reload=reload)
    return(invisible(TRUE))             # return success
  }
  else if (missing(name)) {
    class(libs) <- "UCSLibList"
    return(libs)
  } else {
    if (! name %in% names(libs)) stop("The UCS/R library '", name, "' does not exist.")
    if (reload || !(name %in% names(.ucs.loaded))) {
      filename <- paste(ucs.R.lib, "/", name, ".R", sep="")
      source(filename)
### for debugging of module loader:
###      cat("UCS module", name, "has been loaded\n")
    }
    .ucs.loaded[[ name ]] <<- TRUE
    return(invisible(TRUE))             # return success
  }
}

print.UCSLibList <- function (l) {
  names <- format(names(l))
  for (i in 1:length(l)) {
    cat(names[i], l[[i]], "\n")
  }
}


#################### Cygwin compatibility functions ####################

##   ucs.system(cmd)
##   lines <- ucs.system(cmd, intern=TRUE)
## execute external command through shell (normally system(), but uses shell() or Cygwin's bash.exe under Windows)
ucs.system <- function (cmd, use.bash=TRUE, intern=FALSE) {
  if (ucs.cygwin) {
    if (use.bash) {
      cmd <- gsub("'", "'\"'\"'", cmd)  # escape single quotes
      bash.cmd <- paste(ucs.cygwin.bash, "-c", paste("'", cmd, "'", sep=""))
      system(bash.cmd, intern=intern, show=!intern, wait=TRUE)
    } else {
      shell(cmd, intern=intern)
    }
  } else {
    system(cmd, intern=intern)
  }
}

##   filename <- ucs.tempfile(pattern)
## front-end to tempfile() which produces a Cygwin-compatible path under Windows
ucs.tempfile <-  function (pattern="tmp") {
  if (ucs.cygwin) {
    name <- tempfile(pattern, tmpdir=ucs.cygwin.tmpdir)
    chartr("\\","/", name)              # translate filename to consistently use forward slashes
  } else {
    tempfile(pattern)
  }
}

##    matches <- ucs.rmatch(pattern, lines)
## similar to pmatch, but matches a single string pattern as _suffix_ of lines
## (easy with Perl-compatible regexps, but needs a trick under Windows where they aren't supported)
ucs.string.rev <- function (x) sapply(lapply(strsplit(x, NULL), rev), paste, collapse="") # from the 'strsplit' manpage
ucs.rmatch <- function (pattern, lines) {
  if (ucs.cygwin) {
    l.p <- nchar(pattern)
    rev.lines <- ucs.string.rev(lines)
    rev.pattern <- ucs.string.rev(pattern)
    idx <- substr(rev.lines, 1, l.p) == rev.pattern
    lines[idx]
  } else {
    grep(paste("\\Q", pattern, "\\E$", sep=""), lines, value=TRUE, perl=TRUE) # use PCRE to match literally
  }
}

