### Name: eo.setup
### Title: Initialise and Finalise an (e,o) Plot (eo)
### Aliases: eo.setup eo.close
### Keywords: UCS hplot

### ** Examples


ucs.library("eo")

## load data set file, add jitter, and reduce to random 10
ds <- add.jitter(read.ds.gz("dickens.ds.gz"))
select <- rbinom(nrow(ds), 1, .1) == 1 
ds <- ds[select,]

## 1) set up new (e,o) plot with suitable axis ranges
eo.setup(ds=ds)  # note that y axis is extend to enforce 1:1 aspect

## 2) add data set as point cloud and three iso-lines
eo.points(ds, style=5, jitter=TRUE)
eo.iso("Poisson.pv", 3, style=1)  # p-value = 1e-3
eo.iso("z.score", 3.09, style=2)  # corresponding one-sided z-score
eo.iso("t.score", 3.09, style=3)  # same as t-score with df=Inf

## 3) add legend boxes in top right (2) and bottom right (3) corner
eo.legend.points(2, "pair type", 5)
eo.legend.iso(3, c("Poisson", "z-score", "t-score"), 1:3)

## 4) finalise the (e,o) plot
eo.close()




