% --- Source file: man/Cbeta.Rd ---
\name{Cbeta}
\alias{Cbeta}
\title{The Beta Function (sfunc)}
\description{
  Computes the (complete) Beta function and its base 10 logarithm. 
}
\usage{
Cbeta(a, b, log=FALSE)
}
\arguments{
  \item{a, b}{numeric vectors}
  \item{log}{if \code{TRUE}, returns the base 10 logarithm of the Beta
    function (default: \code{FALSE})}
}
\value{
  The Beta function with arguments (\code{a}, \code{b}), or its base 10
  logarithm (if \code{log=TRUE}).
}
\details{
  This is just a front-end to the built-in \code{beta} and
  \code{lbeta} functions, provided mainly for consistent naming.
  Note that the logarithmic version is scaled to base 10 logarithms,
  according to the UCS conventions.
}
\seealso{
  \code{beta}, \code{\link{Ibeta}}, \code{\link{Rbeta}}, \code{\link{Cgamma}},
  \code{\link{Igamma}}, \code{\link{Rgamma}}
}
\examples{
x <- 5
y <- 3
((x+y+1) * beta(x+1,y+1))^-1 # == choose(x+y, x)
}
\keyword{UCS}
\keyword{math}

\eof
% --- Source file: man/Cgamma.Rd ---
\name{Cgamma}
\alias{Cgamma}
\title{The Gamma Function (sfunc)}
\description{
  Computes the (complete) Gamma function and its base 10 logarithm. 
}
\usage{
Cgamma(a, log=FALSE)
}
\arguments{
  \item{a}{a numeric vector}
  \item{log}{if \code{TRUE}, returns the base 10 logarithm of the Gamma
    function (default: \code{FALSE})}
}
\value{
  The Gamma function evaluated at \code{a}, or its base 10 logarithm
  (if \code{log=TRUE}).
}
\details{
  This is just a front-end to the built-in \code{gamma} and
  \code{lgamma} functions, provided mainly for consistent naming.
  Note that the logarithmic version is scaled to base 10 logarithms,
  according to the UCS conventions.
}
\seealso{
  \code{gamma}, \code{\link{Igamma}}, \code{\link{Rgamma}}, \code{\link{Cbeta}},
  \code{\link{Ibeta}}, \code{\link{Rbeta}}
}
\examples{
Cgamma(5 + 1) # = factorial(5)
}
\keyword{UCS}
\keyword{math}

\eof
% --- Source file: man/EV.Rd ---
\name{EV}
\alias{EV}
\alias{EV.zm}
\alias{EV.fzm}
\title{Expected Vocabulary Size of a LNRE Model (zm, fzm)}
\description{
  Computes the expected vocabulary size of a LNRE model (Baayen, 2001)
  at sample size \eqn{N}.
}
\usage{
EV(model, N)
}
\arguments{
  \item{model}{an object of class \code{"zm"} or \code{"fzm"},
    representing a Zipf-Mandelbrot (ZM) or finite Zipf-Mandelbrot (fZM)
    LNRE model}
  \item{N}{a vector of positive integers, representing sample sizes}
}
\value{
  a numeric vector of the same length as \code{N}
}
\details{
  The expected vocabulary size \eqn{E[V(N)]} is the expected number of
  types at sample size \eqn{N}, according to the LNRE model \code{model}
  (see Baayen, 2001).
}
\references{
  Baayen, R. Harald (2001). \emph{Word Frequency Distributions.} Kluwer,
  Dordrecht.
}
\seealso{
  \code{\link{zm}}, \code{\link{fzm}}, \code{\link{EVm}},
  \code{\link{VV}}, \code{\link{VVm}}
}
\keyword{UCS}
\keyword{models}
\keyword{LNRE}

\eof
% --- Source file: man/EVm.Rd ---
\name{EVm}
\alias{EVm}
\alias{EVm.zm}
\alias{EVm.fzm}
\title{Expected Frequency Spectrum of a LNRE Model (zm, fzm)}
\description{
  Computes the expected frequency spectrum, relative frequency spectrum,
  and conditional parameter distribution of a LNRE model (Baayen, 2001)
  at sample size \eqn{N}.
}
\usage{
EVm(model, m, N, rho=1, relative=FALSE, ratio=FALSE, lower=TRUE)
}
\arguments{
  \item{model}{an object of class \code{"zm"} or \code{"fzm"},
    representing a Zipf-Mandelbrot (ZM) or finite Zipf-Mandelbrot (fZM)
    LNRE model}
  \item{m}{a vector of positive integers, representing frequency ranks}
  \item{N}{a vector of positive integers, representing sample sizes;
    either \code{m} or \code{N} should be a single number}
  \item{rho}{a vector of numbers in the range \eqn{[0,1]}.  If
    \code{length(rho) > 1}, both \code{m} and \code{N} should be single
    numbers.  See below for details.}
  \item{relative}{if \code{TRUE}, computes the relative frequency
    spectrum (see below for details)}
  \item{ratio}{if \code{TRUE}, computes the ratio between consecutive
    elements in the expected frequency spectrum}
  \item{lower}{if \code{rho} is specified, controls whether the lower or
    upper conditional parameter distribution is computed}
}
\value{
  a numeric vector of appropriate length (determined either by \code{m},
  \code{N}, or \code{rho})
}
\details{
  The expected frequency spectrum consists of the numbers
  \eqn{E[V_m(N)]}, which stand for the expected number of types in
  frequency class \eqn{m} at sample size \eqn{N}, according to the LNRE
  model \code{model} (see Baayen, 2001).

  If \code{relative=TRUE}, the relative frequency spectrum
  \eqn{E[V_m(N)] / E[V(N)]} is returned.  If \code{ratio=TRUE}, the
  ratios between consecutive expected class sizes, \eqn{E[V_{m+1}(N)] /
    E[V_m(N)]}, are returned.

  When \code{rho} is specified, the conditional parameter distribution
  \eqn{E[V_{m,\rho}(N)]} is returned, i.e. the expected number of types
  in frequency class \eqn{m} at sample size \eqn{N} with probability
  parameter \eqn{\pi \le \rho}.  If \code{relative=TRUE}, the expected
  proportion \eqn{E[R_{m,\rho}] \approx E[V_{m,\rho}(N)] / E[V(N)]} is
  returned instead.  With \code{lower=FALSE}, computes the upper
  conditional parameter distribution \eqn{E[V_{m,>\rho}(N)]} or
  proportion \eqn{E[R_{m,>\rho}(N)]}. See Evert (2004, Ch. 4) for
  details.
}
\references{
  Baayen, R. Harald (2001). \emph{Word Frequency Distributions.} Kluwer,
  Dordrecht.

  Evert, Stefan (2004). \emph{The Statistics of Word Cooccurrences: Word
    Pairs and Collocations.} PhD Thesis, IMS, University of Stuttgart.
}
\seealso{
  \code{\link{zm}}, \code{\link{fzm}}, \code{\link{EVm}},
  \code{\link{VV}}, \code{\link{VVm}}
}
\keyword{UCS}
\keyword{models}
\keyword{LNRE}

\eof
% --- Source file: man/Ibeta.Rd ---
\name{Ibeta}
\alias{Ibeta}
\alias{Ibeta.inv}
\title{The Incomplete Beta Function (sfunc)}
\description{
  Computes the incomplete Beta function and its inverse.  The
  Beta value can be scaled to a base 10 logarithm.
}
\usage{
Ibeta(x, a, b, log=FALSE)

Ibeta.inv(y, a, b, log=FALSE)
}
\arguments{
  \item{a, b}{non-negative numeric vectors, the parameters of the
    incomplete Beta function}
  \item{x}{a numeric vector with values in the range \eqn{[0,1]}, the
    point at which the incomplete Beta function is evaluated}
  \item{y}{a numeric vector, the values of the incomplete Beta function
    (or their base 10 logarithms if \code{log=TRUE})}
  \item{log}{if \code{TRUE}, the Beta values are base 10 logarithms
    (default: \code{FALSE})}
}
\value{
  \code{Ibeta} returns the incomplete Beta function with parameters
  (\code{a},\code{b}) evaluated at point \code{x}.

  \code{Ibeta.inv} returns the point \code{x} at which the incomplete
  Beta function with parameters (\code{a},\code{b}) evaluates to
  \code{y}. 
}
\details{
  The incomplete Beta function is defined by the Beta integral
  \deqn{B(x;a,b) = \int_0^x t^{a-1} (1-t)^{b-1}\,dt}{%
    B(x;a,b) = integral_0^x t^(a-1) (1-t)^(b-1) dt
  }
}
\seealso{
  \code{\link{Cgamma}}, \code{\link{Igamma}}, \code{\link{Rgamma}},
  \code{\link{Cbeta}}, \code{\link{Rbeta}}
}
\keyword{UCS}
\keyword{math}

\eof
% --- Source file: man/Igamma.Rd ---
\name{Igamma}
\alias{Igamma}
\alias{Igamma.inv}
\title{The Incomplete Gamma Function (sfunc)}
\description{
  Computes the incomplete Gamma function and its inverse.  Both the
  lower and the upper incomplete Gamma function are supported, and the
  Gamma value can be scaled to a base 10 logarithm.
}
\usage{
Igamma(a, x, lower=TRUE, log=FALSE)

Igamma.inv(a, y, lower=TRUE, log=FALSE)
}
\arguments{
  \item{a}{a non-negative numeric vector, the parameter of the
    incomplete Gamma function}
  \item{x}{a non-negative numeric vector, the point at which the
    incomplete Gamma function is evaluated}
  \item{y}{a numeric vector, the values of the incomplete Gamma function
    (or their base 10 logarithms if \code{log=TRUE})}
  \item{lower}{if \code{TRUE}, computes the lower incomplete Gamma
    function (default).  Otherwise, computes the upper incomplete Gamma
    function.}
  \item{log}{if \code{TRUE}, the Gamma values are base 10 logarithms
    (default: \code{FALSE})}
}
\value{
  \code{Igamma} returns the (lower or upper) incomplete Gamma
  function with parameter \code{a} evaluated at point \code{x}.

  \code{Igamma.inv} returns the point \code{x} at which the (lower or
  upper) incomplete Gamma function with parameter \code{a} evaluates to
  \code{y}. 
}
\details{
  The upper incomplete Gamma function is defined by the Gamma integral
  \deqn{\Gamma(a,x) = \int_x^{\infty} t^{a-1} e^{-t}\,dt}{%
    Gamma(a,x) = integral_x^Inf t^(a-1) exp(-t) dt
  }
  The lower incomplete Gamma function is defined by the complementary
  Gamma integral
  \deqn{\gamma(a,x) = \int_0^x t^{a-1} e^{-t}\,dt}{%
    gamma(a,x) = integral_0^x t^(a-1) exp(-t) dt
  }
}
\seealso{
  \code{\link{Cgamma}}, \code{\link{Rgamma}}, \code{\link{Cbeta}},
  \code{\link{Ibeta}}, \code{\link{Rbeta}}
}
\keyword{UCS}
\keyword{math}

\eof
% --- Source file: man/Rbeta.Rd ---
\name{Rbeta}
\alias{Rbeta}
\alias{Rbeta.inv}
\title{The Regularized Beta Function (sfunc)}
\description{
  Computes the regularized Beta function and its inverse.  The
  Beta value can be scaled to a base 10 logarithm.
}
\usage{
Rbeta(x, a, b, log=FALSE)

Rbeta.inv(y, a, b, log=FALSE)
}
\arguments{
  \item{a, b}{non-negative numeric vectors, the parameters of the
    regularized Beta function}
  \item{x}{a numeric vector with values in the range \eqn{[0,1]}, the
    point at which the regularized Beta function is evaluated}
  \item{y}{a numeric vector, the values of the regularized Beta function
    (or their base 10 logarithms if \code{log=TRUE})}
  \item{log}{if \code{TRUE}, the Beta values are base 10 logarithms
    (default: \code{FALSE})}
}
\value{
  \code{Rbeta} returns the regularized Beta function with parameters
  (\code{a},\code{b}) evaluated at point \code{x}.

  \code{Rbeta.inv} returns the point \code{x} at which the regularized
  Beta function with parameters (\code{a},\code{b}) evaluates to
  \code{y}. 
}
\details{
  The regularized Beta function scales the incomplete Beta function to
  the interval \eqn{[0,1]}, by dividing through \eqn{B(a,b)}, i.e.
  \deqn{I(x;a,b) = \frac{B(x;a,b)}{B(a,b)}}{%
    I(x;a,b) = B(x;a,b) / B(a,b)
  }
}
\seealso{
  \code{\link{Cgamma}}, \code{\link{Igamma}}, \code{\link{Rgamma}},
  \code{\link{Cbeta}}, \code{\link{Ibeta}}
}
\keyword{UCS}
\keyword{math}

\eof
% --- Source file: man/Rgamma.Rd ---
\name{Rgamma}
\alias{Rgamma}
\alias{Rgamma.inv}
\title{The Regularized Gamma Function (sfunc)}
\description{
  Computes the regularized Gamma function and its inverse.  Both the
  lower and the upper regularized Gamma function are supported, and the
  Gamma value can be scaled to a base 10 logarithm.
}
\usage{
Rgamma(a, x, lower=TRUE, log=FALSE)

Rgamma.inv(a, y, lower=TRUE, log=FALSE)
}
\arguments{
  \item{a}{a non-negative numeric vector, the parameter of the
    incomplete Gamma function}
  \item{x}{a non-negative numeric vector, the point at which the
    incomplete Gamma function is evaluated}
  \item{y}{a numeric vector, the values of the regularized Gamma function
    (or their base 10 logarithms if \code{log=TRUE})}
  \item{lower}{if \code{TRUE}, computes the lower regularized Gamma
    function (default).  Otherwise, computes the upper regularized Gamma
    function.}
  \item{log}{if \code{TRUE}, the Gamma values are base 10 logarithms
    (default: \code{FALSE})}
}
\value{
  \code{Rgamma} returns the (lower or upper) regularized Gamma
  function with parameter \code{a} evaluated at point \code{x}.

  \code{Rgamma.inv} returns the point \code{x} at which the (lower or
  upper) regularized Gamma function with parameter \code{a} evaluates to
  \code{y}. 
}
\details{
  The regularized Gamma functions scale the corresponding incomplete
  Gamma functions to the interval \eqn{[0,1]}, by dividing through
  \eqn{\Gamma(a)}.  Thus, the lower regularized Gamma function is given
  by
  \deqn{P(a,x) = \frac{\gamma(a,x)}{\Gamma(a)}}{%
    P(a,x) = gamma(a,x) / Gamma(a)
  }
  and the upper regularized Gamma function is given by
  \deqn{Q(a,x) = \frac{\Gamma(a,x)}{\Gamma(a)}}{%
    Q(a,x) = Gamma(a,x) / Gamma(a)
  }
}
\seealso{
  \code{\link{Cgamma}}, \code{\link{Igamma}}, \code{\link{Cbeta}},
  \code{\link{Ibeta}}, \code{\link{Rbeta}}
}
\examples{
## P(X >= k) for Poisson distribution with mean alpha
alpha <- 5
k <- 10
Rgamma(k, alpha) # == ppois(k-1, alpha, lower=FALSE)
}
\keyword{UCS}
\keyword{math}

\eof
% --- Source file: man/UCS.Rd ---
\name{UCS}
\alias{UCS}
\alias{ucs}
\title{Introduction to UCS/R}
\description{

  UCS/R consists of a set of \R libraries related to the
  visualisation of cooccurrence data and the evaluation of association
  measures. The current functionaliy includes: evaluation graphs for association
  measures (in terms of precision and recall), measures for
  inter-annotator agreement, and two population models for word
  frequency distributions.

}
\synopsis{}
\usage{

source("/path/to/UCS/System/R/lib/ucs.R")
ucs.library()

}
\details{

  UCS/R is initialised by \code{source}ing the file
  \file{ucs.R} in the \file{lib/} subdirectory of the UCS/R
  directory tree.  This will make the UCS/R documentation
  available in the \R process and provide the \code{\link{ucs.library}}
  command, which is used to load individual UCS/R modules.
  Enter \code{ucs.library()} now to display a list of available modules
  (see the \code{\link{ucs.library}} manpage for details).

  Currently, the following modules are available.  The listing below
  also indicates the most important manpages for each module.
  Throughout the documentation, it is assumed that you are familiar with
  the UCS/Perl naming conventions and data set file format.

  \itemize{

    \item  \code{sfunc:}  \bold{Special Mathematical Functions}

    Convenience interfaces to the Gamma function (\code{\link{Cgamma}}),
    the incomplete (and regularized) Gamma function and its inverse
    (\code{\link{Igamma}}, \code{\link{Rgamma}}), the Beta function
    (\code{\link{Cbeta}}), the incomplete (and regularized) Beta
    function and its inverse (\code{\link{Ibeta}}, \code{\link{Rbeta}}),
    and binomial confidence intervals
    (\code{\link{binom.conf.interval}}).

    All these functions are computed from the \code{pgamma} and
    \code{pbeta} distributions (and the corresponding quantile
    functions) in the standard library of \R.
    
    \item  \code{base}:  \bold{Basic Functions for Loading and Managing
      UCS data sets}

    This module provides functions for loading UCS data set
    files (\code{\link{read.ds.gz}}), listing annotated association
    measures (\code{\link{ds.find.am}}, \code{\link{am.key2var}}),
    ranking by association scores  (\code{\link{order.by.am}},
    \code{\link{add.ranks}}), and computing
    precision/recall tables for the evaluation of association measures
    (\code{\link{precision.recall}}).

    The module also includes a listing of all built-in association
    measures in the UCS/Perl system, including add-on
    packages (\code{\link{builtin.ams}}).
    
    \item  \code{plots}:  \bold{Evaluation Graphs for Association Measures}

    This module plots precision-, recall-, and precision-by-recall
    graphs for the empirical evaluation of association measures (all
    combined in a single function, \code{\link{evaluation.plot}}).
    The graphs are highly configurable, either locally in each function
    call or by setting global defaults (\code{\link{ucs.par}}).
    The \code{evaluation.plot} function supports confidence
    intervals, significance tests for result differences, and evaluation
    based on random samples (see Evert, 2004, Ch. 5).
    A simple text-mode version of the precision/recall-based evaluation
    is provided by the \code{\link{evaluation.table}} function in the
    \code{base} module.
    
    \item  \code{iaa}:  \bold{Measures of Inter-Annotator Agreement}

    Computes Cohen's kappa statistic with standard deviation (Fleiss,
    Cohen & Everitt, 1969) or confidence interval for proportion of
    true agreement (Krenn, Evert & Zinsmeister, 2004) from a
    \eqn{2\times 2}{2-by-2} contingency table (see
    \code{\link{iaa.kappa}} and \code{\link{iaa.pta}})

    \item \code{gam}:  \bold{Generalised association measures (GAMs)}

    This module implements extensions of several association measures
    to continuous functions on a real-valued coordinate space
    (generalised association measures, GAMs).  For details and
    terminology, please refer to Evert (2004, Sec. 3.3).  The functions
    in this module compute GAM scores and iso-surfaces in standard or
    ebo-coordinates, and can add jitter to a given data set.  New GAMs
    can easily be added with the \code{\link{register.gam}} function.
    Relevant help pages are \code{\link{builtin.gams}},
    \code{\link{gam.score}}, \code{\link{gam.iso}},
    \code{\link{gamma.nbest}}, \code{\link{add.jitter}},
    \code{\link{add.gams}}, \code{\link{add.ebo}},
    and \code{\link{gam.helpers}}.

    \item  \code{eo}:  \bold{Visualise GAMs in the (e,o) plane}

    This module implements 2-D visualisation of data sets and GAMs by
    plotting point clouds and iso-lines in the (e,o) plane (see Evert
    2004, Sec. 3.3).  The recommended starting point is the
    documentation of the \code{\link{eo.setup}} function, which
    intialises a new (e,o) plot.  Other relevant help pages are
    \code{\link{eo.par}}, \code{\link{eo.points}}, \code{\link{eo.iso}},
    \code{\link{eo.iso.diff}}, \code{\link{eo.legend}} and
    \code{\link{eo.mark}}.
    
    \item  \code{lexstats}:  \bold{Utilities for lexical statistics}

    This module contains miscellaneous utility functions for word
    frequency distributions, including: an interface to file
    formats used by the \code{lexstats} software (Baayen 2001);
    a range of common plots; goodness-of-fit evaluation for LNRE
    populations models (cf. the \code{zm} and \code{fzm} modules
    below).  Currently, the most useful functions in this module
    are \code{\link{read.spectrum}}, \code{\link{spectrum.plot}},
    and \code{\link{lnre.goodness.of.fit}}.

    \item  \code{zm}:  \bold{The Zipf-Mandelbrot (ZM) Population Model}

    This module implements a simple population model for word frequency
    distributions (Baayen, 2001) based on the Zipf-Mandelbrot law.  See
    (Evert, 2004a) for details.  Relevant help pages are
    \code{\link{zm}}, \code{\link{EV}}, \code{\link{EVm}},
    \code{\link{VV}}, \code{\link{VVm}},
    \code{\link{write.lexstats}}, and \code{\link{lnre.goodness.of.fit}}.
    
    \item  \code{fzm}:  \bold{The Finite Zipf-Mandelbrot (fZM)
      Population Model}

    This module implements the finite Zipf-Mandelbrot model, an
    extension of the ZM model (Evert, 2004a). Relevant help pages are
    \code{\link{fzm}}, \code{\link{EV}}, \code{\link{EVm}}, 
    \code{\link{VV}}, \code{\link{VVm}},
    \code{\link{write.lexstats}}, and \code{\link{lnre.goodness.of.fit}}.

  }

  The command \code{help(package=UCS)} will give you a full index of
  available UCS/R help pages.  Use \code{help.search()} for
  full-text search.

}
\note{

  The correct \code{source} path for the file \file{ucs.R} can be set
  automatically with the UCS/Perl tool \code{ucs-config}.  Simply
  insert the statement
  \preformatted{
    source("ucs.R")
  }
  on a separate line in your \R script file (say, \file{my-script.R})
  and run the shell command
  \preformatted{
    ucs-config my-script.R
  }

}
\references{

  Baayen, R. Harald (2001). \emph{Word Frequency Distributions.} Kluwer,
  Dordrecht.

  Evert, Stefan (2004). \emph{The Statistics of Word Cooccurrences: Word
    Pairs and Collocations.} PhD Thesis, IMS, University of Stuttgart.

  Evert, Stefan (2004a). A simple LNRE model for random character
  sequences. In \emph{Proceedings of JADT 2004}, Louvain-la-Neuve,
  Belgium, pages 411--422.

  Fleiss, Joseph L.; Cohen, Jacob; Everitt, B. S. (1969). Large sample
  standard errors of kappa and weighted kappa. \emph{Psychological
    Bulletin}, \bold{72}(5), 323--327.
  
  Krenn, Brigitte; Evert, Stefan; Zinsmeister, Heike (2004). Determining
  intercoder agreement for a collocation identification task.  In
  preparation.

}
\seealso{

  \code{\link{ucs.library}}, the UCS/R tutorial
  (\file{tutorial.R} in the \file{script/} subdirectory) and the
  UCS/Perl documentation.

}
\keyword{UCS}
\keyword{utilities}          

\eof
% --- Source file: man/VV.Rd ---
\name{VV}
\alias{VV}
\alias{VV.zm}
\alias{VV.fzm}
\title{Variance of the Vocabulary Size of a LNRE Model (zm, fzm)}
\description{
  Computes the variance of the vocabulary size of a LNRE model (Baayen,
  2001) at sample size \eqn{N}.
}
\usage{
VV(model, N)
}
\arguments{
  \item{model}{an object of class \code{"zm"} or \code{"fzm"},
    representing a Zipf-Mandelbrot (ZM) or finite Zipf-Mandelbrot (fZM)
    LNRE model}
  \item{N}{a vector of positive integers, representing sample sizes}
}
\value{
  a numeric vector of the same length as \code{N}
}
\details{
  The variance \eqn{V[V(N)]} is computed according to Baayen (2001,
  120f). See the \code{\link{EV}} help page for some more information
  on the vocabulary size \eqn{V(N)}.
}
\references{
  Baayen, R. Harald (2001). \emph{Word Frequency Distributions.} Kluwer,
  Dordrecht.
}
\seealso{
  \code{\link{zm}}, \code{\link{fzm}}, \code{\link{VVm}},
  \code{\link{EV}}, \code{\link{EVm}}
}
\keyword{UCS}
\keyword{models}
\keyword{LNRE}

\eof
% --- Source file: man/VVm.Rd ---
\name{VVm}
\alias{VVm}
\alias{VVm.zm}
\alias{VVm.fzm}
\title{Variances of the Frequency Spectrum of a LNRE Model (zm, fzm)}
\description{
  Computes the variances of the frequency spectrum and conditional
  parameter distribution of a LNRE model (Baayen, 2001) at sample size \eqn{N}.
}
\usage{
VVm(model, m, N, rho=1, relative=FALSE, lower=TRUE)
}
\arguments{
  \item{model}{an object of class \code{"zm"} or \code{"fzm"},
    representing a Zipf-Mandelbrot (ZM) or finite Zipf-Mandelbrot (fZM)
    LNRE model}
  \item{m}{a vector of positive integers, representing frequency ranks}
  \item{N}{a vector of positive integers, representing sample sizes;
    either \code{m} or \code{N} should be a single number}
  \item{rho}{a vector of numbers in the range \eqn{[0,1]}.  If
    \code{length(rho) > 1}, both \code{m} and \code{N} should be single
    numbers.  See below for details.}
  \item{relative}{if \code{TRUE}, computes variances for the relative
    conditional parameter distribution (see below for details).  May
    only be used when \code{rho} is specified.}
  \item{lower}{if \code{rho} is specified, controls whether variances
    are computed for the lower or for the upper conditional parameter
    distribution}
}
\value{
  a numeric vector of appropriate length (determined either by \code{m},
  \code{N}, or \code{rho})
}
\details{
  The variance \eqn{V[V_m(N)]} is computed according to Baayen (2001,
  120f).  

  When \code{rho} is specified, the variances of the conditional
  parameter distribution \eqn{V[V_{m,\rho}(N)]} or the corresponding
  proportions \eqn{V[R_{m,\rho}(N)]} are returned, depending on the
  value of \code{relative}.  With \code{lower=FALSE}, computes variances
  for the upper conditional parameter distribution
  \eqn{V[V_{m,>\rho}(N)]} or proportion \eqn{V[R_{m,>\rho}(N)]}.
  See Evert (2004, Ch. 4) for details.

  The \code{\link{EVm}} help page provides more information about
  \eqn{V_m(N)}, \eqn{V_{m,\rho}(N)}, \eqn{R_{m,\rho}(N)},
  \eqn{V_{m,>\rho}(N)} and \eqn{R_{m,>\rho}(N)}.

  Note that this function does \emph{not} compute variances for the
  relative frequency spectrum (\eqn{V[V_m(N)/V(N)]}) or the ratio
  between consecutive spectrum elements (\eqn{V[V_{m+1}(N)/V_m(N)]}).
}
\references{
  Baayen, R. Harald (2001). \emph{Word Frequency Distributions.} Kluwer,
  Dordrecht.

  Evert, Stefan (2004). \emph{The Statistics of Word Cooccurrences: Word
    Pairs and Collocations.} PhD Thesis, IMS, University of Stuttgart.
}
\seealso{
  \code{\link{zm}}, \code{\link{fzm}}, \code{\link{VVm}},
  \code{\link{EV}}, \code{\link{EVm}}
}
\keyword{UCS}
\keyword{models}
\keyword{LNRE}

\eof
% --- Source file: man/add.gams.Rd ---
\name{add.gams}
\alias{add.gams}
\title{Annotate Data Set with GAM Scores (gam)}
\description{
  Annotates data set with GAM scores, possibly overwriting existing
  scores of a standard AM.  Optionally, \emph{jitter} annotated in the
  data set can be taken into account when computing the scores.
} \usage{
  add.gams(ds, names, jitter=FALSE)
}
\arguments{
  \item{ds}{a UCS data set object}
  \item{name}{a character vector specifying the names of generalised
    association measures to be annotated in the data set}
  \item{add.jitter}{if \code{TRUE}, random jitter (which must be
    annotated in the data set) is added to the frequency signatures
    before computing GAM scores (see details below)}
}
\value{
  a copy of the data set \code{ds} annotated with GAM scores for the
  specified measures
}
\details{
  The \code{add.gams} function uses the standard variable names for AM
  scores (e.g. \code{am.t.score} for the \code{t.score} measure), so that
  existing scores for the respective standard AMs in the data set will
  be overwritten.  Rankings for the GAM scores can then be computed in
  the normal way using the \code{add.ranks} function.

  With \code{jitter=TRUE}, a small amount of random jitter is added to
  the frequency signatures in order to avoid ties in the rankings and
  facilitate visualisation of the data set.  The necessary jitter
  vectors have to be stored in special variables in the data set first,
  which is most easily achieved with the \code{add.jitter} function.
}
\seealso{
  \code{\link{gam.score}}, \code{\link{gam.iso}},
  \code{\link{builtin.gams}}, \code{\link{add.ranks}},
  \code{\link{add.jitter}}
}
\examples{
ds <- add.ranks(add.gams(ds, c("t.score", "chi.squared.corr")))

ds <- add.jitter(ds)		% re-annotate GAMs with jittering
gam.names <- ds.find.am(ds)
gam.names <- gam.names[ is.builtin.gam(gam.names) ]
ds <- add.gams(ds, gam.names, jitter=TRUE)
ds <- add.ranks(ds, gam.names, randomise=FALSE, overwrite=TRUE)
}
\keyword{UCS}
\keyword{GAM}
\keyword{math}
\eof
% --- Source file: man/add.jitter.Rd ---
\name{add.jitter}
\alias{add.jitter}
\alias{has.jitter}
\alias{add.ebo}
\title{Random Jitter for Frequency Signatures in Data Set (gam)}
\description{
  Add random \emph{jitter} to the frequency signatures in a data set, in
  order to avoid ties in rankings according to GAM scores and to facilitate
  visualisation of the data set with eo and ebo plots.  The
  \code{add.ebo} function is used to re-compute ebo-coordinates from
  the jittered frequency signatures.
} \usage{
  add.jitter(ds, amount=0.5, overwrite=FALSE)

  has.jitter(ds, fail=FALSE)

  add.ebo(ds, jitter=FALSE)
}
\arguments{
  \item{ds}{a UCS data set object}
  \item{amount}{amount of jitter to be added; the jitter vector for each
    coordinate (\code{f, f1, f2}) has a uniform distribution over the
    range \code{[-amount, +amount]}}
  \item{overwrite}{if \code{TRUE}, overwrite existing jitter vectors in
    the data set}
  \item{fail}{if \code{TRUE}, abort with an error message unless the
    data set contains jitter vectors}
  \item{jitter}{if \code{TRUE}, use the jittered frequency signatures to
    compute ebo-coordinates (default: unjittered integer frequencies)}
}
\value{
  \code{add.jitter} and \code{add.ebo} return a copy of the data set
  \code{ds} with the request variables added.  \code{has.jitter} returns
  \code{TRUE} if the jitter variables are present in \code{ds}, and
  \code{FALSE} otherwise.
}
\details{
  The \code{add.jitter} function adds jitter vectors for the joint and
  marginal frequencies (\code{f, f1, f2}) to a data set, i.e. uniformly
  distributed random numbers in the range \code{[-amount, +amount]}.
  These vectors are stored in variables \code{x.jitter.f},
  \code{x.jitter.f1} and \code{x.jitter.f2}, where they can be used by
  \code{add.ebo}, \code{add.gams} and other functions.
  \code{has.jitter} tests for the presence of these variables.
  
  \code{add.ebo} computes ebo-coordinates from the frequency signatures
  and stores them in the standard variables \code{e, b, o}.  Unlike the
  values computed with UCS/Perl tools, \code{add.ebo} uses jitter
  vectors in this computation when the option \code{jitter=TRUE} is passed.
}
\seealso{
  \code{\link{add.gams}}, \code{\link{gamma.nbest}}
}
\examples{
ds <- add.jitter(ds, amount=0.2)

ds <- add.ebo(ds, jitter=TRUE)	# recompute ebo coordinates with jitter
}
\keyword{UCS}
\keyword{GAM}
\keyword{math}
\eof
% --- Source file: man/add.ranks.Rd ---
\name{add.ranks}
\alias{add.ranks}
\title{Compute Rankings for Annotated Association Measures (base)}
\description{
  Add rankings (with or without ties) for specified association measures
  to a data set object.
}
\usage{
add.ranks(ds, keys=ds.find.am(ds), randomise=TRUE, overwrite=TRUE)
}
\arguments{
  \item{ds}{a UCS data set object}
  \item{keys}{a character vector giving the names of one or more
    association measures. When it is omitted, rankings are computed for
    all annotated measures.}
  \item{randomise}{if \code{TRUE}, ties are broken randomly (default).
    Otherwise, tied rows are assigned the same rank, which is the first
    free one (as in the Olympic Games).  See below for prerequisites.}
  \item{overwrite}{if \code{TRUE}, existing rankings are overwritten
    (default). Otherwise, association measures for which ranks are
    already annotated are silently skipped. If you modify association
    scores within \R, be sure to call \code{add.ranks} with
    \code{overwrite=TRUE}.}
}
\value{
  Invisibly returns a copy of \code{ds} annotated with the requested
  rankings. The rankings are stored in variables \code{r.*}, where
  \code{*} stands for the name of an association measure (according to
  the UCS naming conventions, cf. the \code{\link{am.key2var}} manpage).
}
\details{
  Since \code{add.ranks} is based on the \code{order.by.am} function,
  the prerequisites are the same: the data set must contain association
  scores for the \code{random} measure if \code{randomise=TRUE} and an
  \code{id} variable if \code{randomise=FALSE}.  See the
  \code{\link{order.by.am}} manpage for further information.
}
\seealso{
  \code{\link{order.by.am}}, \code{\link{am.key2var}},
  \code{\link{ds.find.am}}, \code{\link{read.ds.gz}}
}
\examples{
## from the UCS/R tutorial
GLAW <- read.ds.gz("glaw.scores.ds.gz")
GLAW <- add.ranks(GLAW)

## combine into single command
GLAW <- add.ranks(read.ds.gz("glaw.scores.ds.gz"))  
}
\keyword{UCS}

\eof
% --- Source file: man/am.key2var.Rd ---
\name{am.key2var}
\alias{am.key2var}
\alias{am.var2key}
\alias{is.valid.key}
\title{UCS Variable Names for Association Scores and Rankings (base)}
\description{
  These functions implement the UCS naming conventions for variables
  storing association scores and the corresponding ranking.
  \code{is.valid.key} checks whether a given string is valid as a name
  for an association measure. \code{am.key2var} translates a valid AM
  name into the corresponding variables (for scores or ranking), and
  \code{am.var2key} extracts the AM name from such a variable.
}
\usage{
is.valid.key(key, warn=FALSE)

am.key2var(key, rank=FALSE)

am.var2key(var)
}
\arguments{
  \item{key}{a character vector, giving the names of one or more
    association measures}
  \item{var}{a character vector of variable names, which must be either
    association scores or rankings (but both types can be mixed in the
    vector)}
  \item{warn}{if \code{TRUE}, issues a warning if the vector \code{key}
    contains invalid AM names. All invalid entries are listed in the
    warning message.}
  \item{rank}{if \code{TRUE}, return names of the ranking variables
    corresponding to the specified association measures. otherwise,
    return names of variables for association scores.}
}
\value{
  \code{is.valid.key} returns a logical vector, \code{am.var2key}
  returns a list of AM names (\dQuote{keys}), and \code{am.key2var}
  returns a list of variable names (either for association scores or
  rankings, depending on the \code{rank} parameter).
}
\seealso{
  \code{\link{builtin.ams}} for information about built-in association
  measures, and the \code{ucsfile} manpage in UCS/Perl for a description
  of the UCS naming conventions (enter the shell command \code{ucsdoc
    ucsfile}).
}
\examples{
am.key2var(c("t.score", "MI"), rank=TRUE)
am.var2key(c("am.t.score", "r.MI"))
}
\keyword{UCS}

\eof
% --- Source file: man/binom.conf.interval.Rd ---
\name{binom.conf.interval}
\alias{binom.conf.interval}
\title{Binomial Confidence Intervals}
\description{
  Computes confidence intervals for the success probability of a
  binomial distribution efficiently.  Unlike \code{binom.test}, this
  function can be applied to vectors.
}
\usage{
binom.conf.interval(k, size, limit=c("lower","upper"),
                    conf.level=0.05, one.sided=FALSE)
}
\arguments{
  \item{k}{a vector of non-negative integers.  Each element represents
    the number of successes out of \code{size} trials, i.e. the observed
    value of a random variable with binomial distribution.}
  \item{size}{a vector of positive integers.  Each element represents
    the number of trials of a binomial distribution.}
  \item{limit}{if \code{"upper"}, the upper boundaries of the confidence
    intervals are returned. If \code{"lower"}, the lower boundaries are
    returned.  Note that this works both for one-sided and for two-sided
    confidence intervals.}
  \item{conf.level}{the required confidence level, or rather the
    significance level of the corresponding binomial test (note that
    this behaviour differs from the built-in \code{binom.test}
    function). The default \code{conf.level=0.05} stands for 95\% confidence.}
  \item{one.sided}{if \code{TRUE}, computes one-sided confidence
    interval (either lower or upper, depending on the value of
    \code{limit}).  If \code{FALSE}, a two-sided confidence interval is
    computed (default).}
}
\value{
  A numeric vector with the requested boundary of confidence intervals
  for the unknown success probabilities of binomial variables.
}
\details{
  If \code{one.sided=TRUE}, the underlying test is one-sided (with
  alternative \code{"less"} or \code{"greater"}, depending on the 
  \code{limit} parameter), and the non-trivial boundary of the
  confidence interval is returned.

  If \code{one.sided=FALSE}, the underlying test is two-sided and
  the requested boundary of the two-sided confidence interval is
  returned.  For efficiency reasons, the \code{binom.conf.interval}
  function cheats a little and computes one-sided confidence intervals
  with significance level \code{conf.level / 2}.
}
\seealso{
  \code{binom.test}
}
\keyword{UCS}
\keyword{htest}

\eof
% --- Source file: man/builtin.ams.Rd ---
\name{builtin.ams}
\alias{builtin.ams}
\alias{is.builtin.am}
\alias{am.key2desc}
\title{UCS/Perl Built-in Association Measures (base)}
\description{
  \code{builtin.ams} returns a character vector listing the built-in
  association measures of the UCS/Perl system (including the standard
  add-on packages), \code{is.builtin.am} checks whether a specified
  measure belongs to this set, and \code{am.key2desc} returns a short
  description of the specified measure.
}
\usage{
builtin.ams()

is.builtin.am(key)

am.key2desc(key)
}
\arguments{
  \item{key}{a character vector specifying the names of one or more
    association measures}
}
\value{
  \code{builtin.ams} returns a character vector containing the names of
  all built-in association measures, \code{is.builtin.am} returns a
  logical vector, and \code{am.key2desc} returns a character vector with
  a short description of each of the measures in \code{key}.
}
\seealso{
  The information provided by these functions is obtained from the
  UCS/Perl tool \code{ucs-list-am}.  See the \code{ucsam} manpage in
  UCS/Perl for further information about built-in association
  measures (using the shell command \code{ucsdoc ucsam}).  
}
\examples{
print(builtin.ams())
am.key2desc("chi.squared.corr")
}
\keyword{UCS}

\eof
% --- Source file: man/builtin.gams.Rd ---
\name{builtin.gams}
\alias{builtin.gams}
\alias{is.builtin.gam}
\alias{register.gam}
\title{Built-in Generalised Association Measures (gam)}
\description{
  List available GAMs (generalised association measures) that can
  be computed with functions such as \code{gam.score}, \code{add.gams}
  and \code{gam.iso}, or test whether a specific GAM is available.
  Additional GAMs can be defined with the \code{register.gam} function.
}
\usage{
  builtin.gams()

  is.builtin.gam(names)

  register.gam(name, equation, iso.equation=NULL)
}
\arguments{
  \item{names}{a character vector specifying the names of GAMs whose
    availability is tested}
  \item{name}{a single character string specifying the name of a GAM
    that is defined or re-defined}
  \item{equation}{a function that computes GAM scores from standard or
    ebo-coordinates (see below for details)}
  \item{iso.equation}{an optional function that computes iso-surfaces
    in standard or ebo-coordinates (see below for details)}
}
\value{
  \code{builtin.gams} returns a character vector listing the names of
  available GAMs.  \code{is.builtin.gam} returns a logical vector
  indicating which of the GAMs in the vector \code{names} are available.
}
\details{
  The names of built-in GAMs are identical to those of the corresponding
  standard AMs (e.g. \code{t.score} and \code{chi.squared.corr}).

  The \code{equation} argument of \code{register.gam}, i.e. the equation
  defining a new GAM), must be a function with the signature \code{(o,
    e, b, f, f1, f2, N)}.  This function can computes GAM scores either
  from the ebo-coordinates \code{e, b, o} or from the standard
  coordinates \code{f, f1, f2, N}.  It is always invoked with all seven
  arguments, which are guaranteed to be vectors of the same length, and
  must return a vector of corresponding GAM scores.

  When an explicit equation for iso-surfaces \eqn{\{g = \gamma\}}
  exists, it can be made available through the optional argument
  \code{iso.equation}, which expects a function with the signature
  \code{(gamma, e, b, f1, f2, N)}.  Again, all six arguments are
  guaranteed to be vectors of the same length, and the function must
  return the corresponding \eqn{o} (or \eqn{f}) coordinates that
  satisfy the condition \eqn{g(o, e, b) = \gamma} (or \eqn{g(f, f_1,
    f_2, N) = \gamma}).  When the \code{iso.equation} function is
  available for a GAM, it will be used by \code{gam.iso} for greater
  speed and accuracy.  Otherwise, the iso surface is determined by
  a binary search algorithm (which has a unique solution for any
  semi-sound GAM).

  The signatures of the \code{equation} and \code{iso.equation}
  functions are checked by \code{register.gam}, which will abort with an
  error message if they are not correct.
}
\seealso{
  \code{\link{builtin.ams}}, \code{\link{gam.score}},
  \code{\link{add.gams}}, \code{\link{gam.iso}}, \code{\link{gam.helpers}}
}
\examples{
print(builtin.gams())

all(is.builtin.gam(c("MI", "t.score", "chi.squared")))

register.gam("MI5",
             eq  = function (o, e, b, f, f1, f2, N) { log10(o^5 / e) },
             iso = function (gamma, e, b, f1, f2, N) { 10^(gamma/5) * e^(1/5) })
}
\keyword{UCS}
\keyword{GAM}
\keyword{math}
\eof
% --- Source file: man/ds.find.am.Rd ---
\name{ds.find.am}
\alias{am.in.ds}
\alias{ds.find.am}
\alias{ds.match.am}
\title{List Association Scores and Rankings in Data Set (base)}
\description{
  \code{am.in.ds} tests whether a specified association measure is
  annotated in a data set, \code{ds.find.am} lists all annotated
  association measures, and \code{ds.match.am} searches the data set for
  AMs whose names may be abbreviated to a unique prefix.  All three
  functions look either for association scores or for rankings.
}
\usage{
am.in.ds(ds, keys, rank=FALSE, fail=FALSE)

ds.find.am(ds, rank=FALSE)

ds.match.am(ds, abbrevs, rank=FALSE)
}
\arguments{
  \item{ds}{a UCS data set, read from a data set file with the
    \code{read.ds.gz} function}
  \item{keys}{a character vector of AM names}
  \item{abbrevs}{a character vector of AM names, each of which may be
    abbreviated to a unique prefix (within the data set)}
  \item{rank}{if \code{TRUE}, the functions look for annotated rankings;
    otherwise, they look for annotated association scores (default)}
  \item{fail}{if \code{TRUE}, the function aborts with an error message
    unless all specified AMs are annotated in the data set}
}
\value{
  \code{am.in.ds} returns a logical vector of the same length as
  \code{keys}.  \code{ds.find.am} and \code{ds.match.am} return a
  character vector containing the names of the annotated association
  measures.
}
\details{
  If any of the \code{abbrev}s do not have a unique match in the data
  set, \code{ds.match.am} aborts with an error message (listing all
  strings that failed to match uniquely).
}
\seealso{
  \code{\link{read.ds.gz}}, \code{am.var2key}
}
\examples{
GLAW <- read.ds.gz("glaw.scores.ds.gz")
print(ds.find.am(GLAW))
}
\keyword{UCS}

\eof
% --- Source file: man/eo.iso.Rd ---
\name{eo.iso}
\alias{eo.iso}
\title{Draw Iso-Line of a GAM in the (e,o) Plane (eo)}
\description{

  Draw an iso-line of a generalised association measure (GAM) in
  the (e,o) plane, either for a specified cutoff threshold \eqn{\gamma}
  or an n-best iso-line for a given data set \code{ds}.  Optionally,
  the corresponding acceptance region can be shaded or filled with solid
  colour. 

}
\usage{

eo.iso(gam, gamma=0, b=1, N=1e6, n.best=NULL, ds=NULL,
       style=1, fill=solid, solid=FALSE,
       steps=eo.par("steps"), jitter=eo.par("jitter"), bw=bw,
       col=eo.par("col"), lty=eo.par("lty"), lwd=eo.par("lwd"),
       angle=eo.par("angle"), density=eo.par("density"),
       solid.col=eo.par("solid"))

}
\arguments{

  \item{gam}{a character string giving the name of a generalised
    association measure (GAM).  Use the function \code{builtin.gams}
    from the \code{gam} module to obtain a list of available GAMs.}
  
  \item{gamma}{a cutoff threshold that determines the iso-line to be
    drawn (by the implicit equation \eqn{\{g = \gamma\}}).  Use the
    \code{n.best} and \code{ds} parameters instead of \code{gamma} in
    order to obtain an n-best iso-line for the data set \code{ds}.}
  
  \item{b, N}{optional balance (\code{b}) and sample size (\code{N})
    parameters for GAMs that are not central or size-invariant,
    respectively.  The default \code{b=1} yields the centralised version
    of a non-central GAM (for details, see Evert 2004, Sec. 3.3)}
  
  \item{n.best, ds}{When these parameters are specified, the cutoff
    threshold \code{gamma} will automatically be determined so as to
    yield an n-best acceptance region for the data set
    \code{ds}.}

  \item{jitter}{If \code{TRUE}, use jittered coordinates for computing
    the n-best cutoff threshold (see above).  In this case, the data set
    has to be annotated with the \code{add.jitter} function first.}
  
  \item{style}{an integer specifying the style (colour, line type and width)
    in which iso-lines will be drawn.  The number of styles available
    depends on the global parameter settings (\code{eo.par}).  The
    "factory settings" define 5 different styles for iso-lines.}

  \item{fill}{If \code{TRUE}, fill in the acceptance region bounded by
    the given iso-line with shading lines, according to the chosen
    \code{style} and \code{bw mode}.  See \code{eo.par} for details on
    shading styles.}
  
  \item{solid}{If \code{TRUE}, fill the acceptance region with solid
    colour rather than shading lines, also according to the chosen
    \code{style} and \code{bw} mode.  Setting \code{solid=TRUE} implies
    \code{fill=TRUE}.}
  
  \item{steps}{an integer specifying how many equidistant steps are used
    for drawing iso-lines.  The default value is set with \code{eo.par}.}
  
  \item{bw}{If \code{TRUE}, the iso-lines are drawn in B/W mode,
    otherwise in colour mode.  This parameter defaults to the state
    specified with the initial \code{eo.setup} call, but can be
    overridden manually.}

  \item{col, lty, lwd}{can be used to override the default style
    parameters for iso-lines, which are determined automatically from
    the global settings (\code{eo.par}) according to the selected
    \code{style} and \code{bw} mode.}
  
  \item{angle, density}{can be used to override the default style
    parameters for shaded acceptance region, which are determined
    automatically from the global settings (\code{eo.par}) according to
    the selected \code{style} and \code{bw} mode.}
  
  \item{solid.col}{can be used to override the default colour for
    solid filled acceptance regions, which is determined
    automatically from the global settings (\code{eo.par}) according to
    the selected \code{style} and \code{bw} mode.}

}
\details{

  See the \code{\link{eo.setup}} help page for a description of the
  general procedure used to create (e,o) plots.  This help page also has
  links to other (e,o) plotting functions.  The "factory setting" styles
  are described on the \code{\link{eo.par}} help page.

  The cutoff threshold \eqn{\gamma} can either be specified explicitly
  (with the \code{gamma} parameter) or implicitly as an n-best threshold
  (with \code{n.best}, \code{ds}, and optional \code{jitter}).  The
  latter method produces the same result as 
  \preformatted{
    gam.iso(gam, gamma=gamma.nbest(ds, gam, n.best, jitter), ...)
  }

  Visualisation by (e,o) iso-lines is most suitable for GAMs that are
  both central and size-invariant (see Evert 2004, Sec. 3.3).  For
  non-central measures, the \code{eo.iso} function uses a balance value
  of \eqn{b = 1}, yielding a centralised version of the GAM.  Note that
  many non-central GAMs (especially those based on statistical tests,
  such as \code{log.likelihood} and \code{chi.squared}) have only a weak
  dependency on the balance \eqn{b}, so that their centralised
  iso-surfaces (i.e. extrusions of the iso-lines along the b-axis) are
  very similar to the original iso-surfaces.  Other GAMs (most notably
  \code{Dice} and similar measures) are highly dependent on \eqn{b},
  though.  For measures that are not size-invariant, the sample size is
  arbitrarily set to \eqn{N = 10^6}, which is in a realistic range for
  real-life data sets.  You may wish to modify the default value in
  order to match a data set shown in the plot (this is \emph{not} done
  automatically when the \code{ds} parameter is specified), or to
  demonstrate the dependency of iso-lines on \eqn{N}.
  
}
\references{

  Evert, Stefan (2004). \emph{The Statistics of Word Cooccurrences: Word
    Pairs and Collocations.} PhD Thesis, IMS, University of Stuttgart.

}
\seealso{

  \code{\link{eo.par}}, \code{\link{eo.setup}}, \code{\link{eo.iso.diff}}

}
\examples{

## an example can be found on the "eo.setup" help page

}
\keyword{UCS}
\keyword{hplot}
\eof
% --- Source file: man/eo.iso.diff.Rd ---
\name{eo.iso.diff}
\alias{eo.iso.diff}
\title{Highlight Differences between Two Acceptance Regions in the (e,o) Plane (eo)}
\description{

  Compare the acceptance regions of two GAMs by shading the two
  difference sets (cf. Evert 2004, Sec. 5.2.2) in different fill
  styles.  This function should be followed by two \code{eo.iso}
  calls to draw the iso-lines bounding the difference regions.
  
}
\usage{

eo.iso.diff(gam1, gam2, gamma1=0, gamma2=0, b=1, N=1e6,
            n.best1=NULL, n.best2=NULL, ds=NULL,
            style1=4, style2=5, solid=FALSE, bw=bw,
            steps=eo.par("steps"), jitter=eo.par("jitter"),
            col1=eo.par("col"), angle1=eo.par("angle"),
            density1=eo.par("density"), solid.col1=eo.par("solid"),
            col2=eo.par("col"), angle2=eo.par("angle"),
            density2=eo.par("density"), solid.col2=eo.par("solid"))

}
\arguments{

  \item{gam1, gam2}{character strings giving the names of two
    generalised association measures (GAMs).  Use the function
    \code{builtin.gams} from the \code{gam} module to obtain a list of
    available GAMs.}
  
  \item{gamma2, gamma2}{cutoff thresholds that determines the two
    acceptance regions (\eqn{\{g_1 = \gamma_1\}} and \eqn{\{g_1 =
    \gamma_1\}}) to be compared.  You can use \code{n.best} and
    \code{ds} parameters (see below) to compute n-best thresholds
    automatically.}
  
  \item{b, N}{optional balance (\code{b}) and sample size (\code{N})
    parameters for GAMs that are not central or size-invariant,
    respectively.  The default \code{b=1} yields the centralised version
    of a non-central GAM (for details, see Evert 2004, Sec. 3.3).
    Note that the same values are used for both GAMs.}
  
  \item{n.best1, n.best2, ds}{When \code{n.best1} is specified, the
    cutoff threshold \code{gamma1} will automatically be determined so
    as to yield an n-best acceptance region for the data set \code{ds}.
    In the same way, \code{n.best2} computes \code{gamma2} as an n-best
    acceptance threshold.  Note that the data set \code{ds} is used
    for both n-best thresholds.}

  \item{jitter}{If \code{TRUE}, use jittered coordinates for computing
    n-best cutoff thresholds (see above).  In this case, the data set
    has to be annotated with the \code{add.jitter} function first.}
  
  \item{style1, style2}{integer values specifying fill styles for the
    two difference regions.  \code{style1} is used for the region
    \eqn{D_1} of the (e,o) plane accepted by \code{gam1} but not
    \code{gam2}, and \code{style2} for the region \eqn{D_2} accepted by
    \code{gam2} but not \code{gam1}.  Style parameters include the
    colour, angle and density of shading lines, or the solid fill colour
    if \code{solid=TRUE}.  See the \code{\link{eo.par}} help page for
    more information about available fill styles.}
  
  \item{solid}{If \code{TRUE}, fill the difference regions with solid
    colour rather than shading lines, also according to the chosen
    \code{style}s and \code{bw} mode.}
  
  \item{bw}{If \code{TRUE}, the regions are drawn in B/W mode,
    otherwise in colour mode.  This parameter defaults to the state
    specified with the initial \code{eo.setup} call, but can be
    overridden manually.}

  \item{steps}{an integer specifying how many equidistant steps are used
    for the (combined) boundaries of the difference regions.  The
    default value is set with \code{eo.par}.}
  
  \item{col1, col2}{can be used to override the default colours for
    shading lines, which are determined automatically from the global
    settings (\code{eo.par}) according to the selected \code{style}s and
    \code{bw} mode.}
  
  \item{angle1, angle2}{can be used to override the default angles of
    shading lines, which are determined automatically from the global
    settings (\code{eo.par}) according to the selected \code{style}s and
    \code{bw} mode.}
  
  \item{density1, density2}{can be used to override the default
    densities of shading lines, which are determined automatically from
    the global settings (\code{eo.par}) according to the selected
    \code{style}s and \code{bw} mode.}

  \item{solid.col1, solid.col2}{can be used to override the default
    solid fill colours (with \code{solid=TRUE}), which are determined
    automatically from the global settings (\code{eo.par}) according to
    the selected \code{style}s and \code{bw} mode.}

}
\details{

  See the \code{\link{eo.setup}} help page for a description of the
  general procedure used to create (e,o) plots.  This help page also has
  links to other (e,o) plotting functions.  The "factory setting" styles
  are described on the \code{\link{eo.par}} help page.

  See the \code{\link{eo.iso}} help page for details about iso-lines,
  acceptance regions and n-best cutoff thresholds.
  
}
\references{

  Evert, Stefan (2004). \emph{The Statistics of Word Cooccurrences: Word
    Pairs and Collocations.} PhD Thesis, IMS, University of Stuttgart.

}
\seealso{

  \code{\link{eo.par}}, \code{\link{eo.setup}}, \code{\link{eo.iso}}

}
\examples{

## setup code (see "eo.setup" example for a detailed explanation)
ucs.library("eo")
ds <- add.jitter(read.ds.gz("dickens.ds.gz"))
select <- rbinom(nrow(ds), 1, .1) == 1 
ds <- ds[select,]

## comparison of 300-best acceptance regions for Poisson and MI measures
eo.setup(xlim=c(-3,2), ylim=c(0,2), aspect=FALSE)
eo.iso.diff("Poisson.pv", "MI", n.best1=300, n.best2=300, ds=ds, solid=TRUE, jitter=TRUE)
eo.points(ds, style=1, jitter=TRUE)
eo.iso("Poisson.pv", n.best=300, ds=ds, style=4)
eo.iso("MI", n.best=300, ds=ds, style=5)
eo.legend.diff(3, c("Poisson+ / MI-","Poisson- / MI+"), solid=TRUE)
eo.close()

}
\keyword{UCS}
\keyword{hplot}
\eof
% --- Source file: man/eo.legend.Rd ---
\name{eo.legend}
\alias{eo.legend}
\alias{eo.legend.points}
\alias{eo.legend.iso}
\alias{eo.legend.diff}
\title{Draw Legend Box for Point Cloud or Iso-Lines (eo)}
\description{

  Draw a legend box in one of the corners of the active (e,o) plot,
  showing labels for one or more styles of data set points, iso-lines or
  shaded/filled acceptance regions.

}
\usage{

eo.legend.points(corner, legend, styles, bw=bw, cex.mul=2.5, ...)

eo.legend.iso(corner, legend, styles, bw=bw, fill=solid, solid=FALSE,
              lw.add=0, density.mul=2, ...)

eo.legend.diff(corner, legend, style1=4, style2=5,
               bw=bw, solid=FALSE, density.mul=2, ...)

}
\arguments{

  \item{corner}{an integer specifying the corner of the plot where the
    legend box will be drawn (\code{1} = top left, \code{2} = top right,
    \code{3} = bottom right, \code{4} = bottom left)}

  \item{legend}{a character vector specifying labels for the legend box.
    For the \code{eo.legend.diff} function, it must have length 2
    (labels for the difference regions \eqn{D_1} and \eqn{D_2}).}

  \item{styles}{an integer vector specifying display styles for the
    items in the legend box (see the \code{\link{eo.par}} help page for
    more information about display styles).  Note that \code{styles}
    must have exactly the same length as \code{legend}}

  \item{style1, style2}{display styles for the first and second
    difference region (\eqn{D_1} and \eqn{D_2}).  The defaults are set
    to match those of \code{eo.iso.diff}.}
  
  \item{bw}{If \code{TRUE}, the points, lines or shading/colour boxes in
    the legend are drawn in B/W mode; otherwise, they are drawn in
    colour mode. This parameter defaults to the state specified with the
    initial \code{eo.setup} call, but can be overridden manually.}

  \item{fill}{If \code{TRUE}, show the shadings of acceptance regions
    instead of iso-line styles in the legend.}
  
  \item{solid}{If \code{TRUE}, show solid colours instead of shadings
    for acceptance regions in the legend. Setting \code{solid=TRUE}
    implies \code{fill=TRUE}.}

  \item{cex.mul}{numeric factor by which plot symbols are scaled in
    the legend box (with respect to their size in the plot)}

  \item{lw.add}{numeric value added to line widths in the legend box.
    Only needed when widths of iso-lines are too thin to be clearly
    visible in the legend box.}

  \item{density.mul}{numeric factor by which the density of shading
    lines is multiplied in the legend box in order to improve visibility
    of the shading style}

  \item{...}{Any additional parameters are passed through to the
    \code{legend} function used to draw the legend box.}
  
}
\details{

  See the \code{\link{eo.setup}} help page for a description of the
  general procedure used to create (e,o) plots.  This help page also has
  links to other (e,o) plotting functions.  The "factory setting" styles
  are described on the \code{\link{eo.par}} help page.

  \code{eo.legend.points} displays a legend box for point clouds plotted
  with \code{eo.points}; \code{eo.legend.iso} a legend box for iso-lines
  or acceptance regions drawn with \code{eo.iso}; and
  \code{eo.legend.diff} a legend box for differences between two
  acceptance regions that have been highlighted with \code{eo.iso.diff}
  (this is just a convenience wrapper around \code{eo.legend.iso}).
  
  Note that legend boxes can only be created for the default styles set
  with \code{eo.par} since it is not possible to override the style
  parameters manually.
  
}
\seealso{

  \code{\link{eo.par}}, \code{\link{eo.setup}}, \code{\link{eo.points}},
  \code{\link{eo.iso}}, \code{\link{eo.iso.diff}}

}
\examples{

## an example can be found on the "eo.setup" help page

}
\keyword{UCS}
\keyword{hplot}
\eof
% --- Source file: man/eo.mark.Rd ---
\name{eo.mark}
\alias{eo.mark}
\title{Mark Individual Pair Typess in Point Cloud (eo)}
\description{

  Mark individual pair types from a data set in a point cloud plotted
  with the \code{eo.points} function. 

}
\usage{

eo.mark(ds, select, style=1, bw=bw, cex=1.5, lwd=3,
        jitter=eo.par("jitter"))

}
\arguments{

  \item{ds}{a data set containing pair types that have been plotted as a
    point cloud, some or all of which will be marked}

  \item{select}{an expression that will be evaluated on the data set
    \code{ds} to determine the pair types that will be marked.  In order
    to mark the point representing the word pair \emph{black box}, e.g.,
    specify \code{select=(l1 == "black" & l2 == "box")}.}

  \item{style}{an integer specifying the style from which the colour of
    the markers is taken.  Note that the symbol (a thick ring) and its
    size are hard-coded in the function and cannot be changed globally.}

  \item{bw}{If \code{TRUE}, the markers are drawn in B/W mode, otherwise
    in colour mode.  This parameter only affects the colour of the
    marker rings.  It defaults to the state specified with the initial
    \code{eo.setup} call, but can be overridden manually.}

  \item{cex, lwd}{size and thickness of the marker rings.  The default
    values are suitable for the "factory setting" styles used for data
    set points (see \code{eo.points}).}

  \item{jitter}{If \code{TRUE}, the coordinates of pair types are
    jittered for the plot.  This parameter must have the same value as
    in the \code{eo.points} call that was used to plot the point cloud,
    otherwise marker placement will be incorrect.  When
    \code{jitter=TRUE}, the data set has to be annotated with the
    \code{add.jitter} function first.  The default value is set with
    \code{eo.par}.}

}
\details{

  See the \code{\link{eo.setup}} help page for a description of the
  general procedure used to create (e,o) plots.  This help page also has
  links to other (e,o) plotting functions.  The "factory setting" styles
  are described on the \code{\link{eo.par}} help page.

}
\seealso{

  \code{\link{eo.par}}, \code{\link{eo.setup}}, \code{\link{eo.points}}

}
\keyword{UCS}
\keyword{hplot}
\eof
% --- Source file: man/eo.par.Rd ---
\name{eo.par}
\alias{eo.par}
\alias{.eo.PAR}
\title{Graphics Parameters for (e,o) Plots (eo)}
\description{

  Set default graphics parameters for (e,o) plots, similar to
  \code{ucs.par} in the \code{plots} module and \code{par} for general
  graphics parameters. Parameter values can be set by specifying them as
  arguments in \code{name=value} form, or by passing a single list of
  named values. The current values can be queried by giving their names
  as character strings.  

}
\usage{

eo.par(...)

.eo.PAR

}
\arguments{

  \item{...}{either character strings (or vectors) specifying the names
    of parameters to be queried, or parameters to be set in
    \code{name=value} form, or a single list of named values.  Valid
    parameter names are described below.}

}
\value{

  When parameters are set, their former values are returned in an
  invisible named list.  Such a list can be passed as a single argument
  to \code{eo.par} to restore the previous settings.

  When a single parameter is queried, its value is returned directly.
  When two or more parameters are queried, the result is a named list.

  Note the inconsistency, which is the same as for \code{par}: setting
  one parameter returns a list, but querying one parameter returns a
  vector (or a scalar, i.e. a vector of length 1).

}
\details{

  The current default parameters are stored in the global variable
  \code{.eo.PAR}.  They can be queried by giving their names as
  one or more character vectors to \code{eo.par}.  \code{eo.par()} (no
  arguments) returns all \code{eo} graphics parameters.

  Parameters are set by specifying their names and the new values as
  \code{name=value} pairs.  Such a list can also be passed as a single
  argument to \code{eo.par}, which is typically used to restore previous
  parameter values (that have been saved in a list variable).

  In order to restore the "factory settings", reload the module with the
  command \code{ucs.library("eo", reload=TRUE)}.

}
\section{Graphics Parameters for (e,o) Plots}{

  \describe{

    \item{\code{bw}}{If \code{TRUE}, (e,o) plots are created in B/W mode
      by default.}

    \item{\code{xlim}, \code{ylim}}{Integer vectors of length 2,
      specifying default ranges for the e-axis (\code{xlim}) and o-axis
      (\code{ylim}) in orders of magnitude (i.e., base 10 logarithms: -2
      corresponds to .01, 0 corresponds to 1, and 3 corresponds to
      1000).  When the default values are not set, every call to the
      \code{eo.setup} function must either specify \code{xlim} and
      \code{ylim} values or a data set, from which suitable ranges are
      computed.}

    \item{\code{aspect}}{If \code{TRUE}, an aspect ratio of 1:1 is
      enforced for every (e,o) plot, i.e. the axis ranges are extended
      as necessary (assuming a square plotting region).  The factory
      setting is \code{TRUE}.}

    \item{\code{log.marks}}{If \code{TRUE}, tick marks on the axes are
      labelled in logarithmic units, i.e. orders of magnitude.
      Otherwise, absolute numbers are used.  The factory setting is
      \code{FALSE}. (Note that (e,o) plots are always drawn in
      logarithmic scale.)}

    \item{\code{steps}}{An integer specifying the number of equidistant
      steps used for drawing iso-lines.  The factory setting is 100.}

    \item{\code{jitter}}{If \code{TRUE}, always uses jittered
      coordinates for plotting data sets and computing n-best
      thresholds.  Note that all data sets must be annotated with the
      \code{add.jitter} function first.  The factory setting is
      \code{FALSE}.}

    \item{\code{cex}}{Overall character expansion factor (for tick
      marks, axis labels and legends).  The factory setting is
      \code{1.3}.}

    \item{\code{col}}{A character of integer vector specifying line
      colours for the different styles of iso-lines in colour mode (see
      the \code{par} manpage for details on colour specification).
      Values are recycled to match the length of the \code{lty} and
      \code{lwd} parameters when necessary.  The factory setting defines
      5 styles in black, blue, red, magenta and cyan.}

    \item{\code{lty}}{A character or integer vector specifying line
      types for the different styles of iso-lines in colour mode (see
      the \code{par} manpage for details).  Values are recycled to match
      the length of the \code{col} and \code{lwd} parameters when
      necessary.}

    \item{\code{lwd}}{A numeric vector specifying line widths
      for the different styles of iso-lines in colour mode.  Values are
      recycled to match the length of the \code{col} and \code{lty}
      parameters when necessary.}

    \item{\code{angle}, \code{density}}{Numeric vectors specifying the
      angle and density of shading lines when the acceptance region
      bounded by a given iso-line is filled.  These vectors should
      supportas many styles as \code{col}, \code{lty} and \code{lwd}
      above. Details on shading lines can be found on the \code{polygon}
      help page.}

    \item{\code{solid}}{A character or integer vector specifying
      background colours for the different styles of iso-lines when the
      acceptance region is filled with solid colour (rather than shading
      lines).}

    \item{\code{bw.col}, \code{bw.lty}, \code{bw.lwd}}{Colour, line type
      and line width for iso-lines in B/W mode (corresponding to
      \code{col}, \code{lty} and \code{lwd} in colour mode).  The
      factory setting defines 5 styles with solid, dashed, grey, dotted
      and dark grey dot-dash lines.}

    \item{\code{bw.angle}, \code{bw.density}, \code{bw.solid}}{Angle and
      density of shading lines, as well as solid colour, for filled
      acceptance regions in B/W mode (corresponding to \code{angle},
      \code{density} and \code{solid} in colour mode)}

    \item{\code{pt.pch}}{A character or integer vector specifying
      plot symbols for the different styles of data set points in colour
      mode (see the \code{\link{points}} help page for a full list of
      available plot symbols).  Values are recycled to match the length
      of the \code{pt.cex} and \code{pt.col} parameters when necessary.
      The factory setting defines 5 styles with black, green, red,
      yellow and orange dots.}

    \item{\code{pt.cex}}{A numeric vector specifying character expansion
      factors for the different styles of data set points in colour
      mode.  Values are recycled to match the length of the
      \code{pt.pch} and \code{pt.col} parameters when necessary.
    }

    \item{\code{pt.col}}{A character or integer vector specifying
      colours for the different styles of data set points in colour
      mode (see the \code{\link{par}} help page for details on
      colour specification).  Values are recycled to match the length
      of the \code{pt.pch} and \code{pt.cex} parameters when necessary.}

    \item{\code{bw.pt.pch}, \code{bw.pt.cex}, \code{bw.pt.col}}{Plot
      symbol, character expansion and colour for data set points in B/W
      mode (corresponding to \code{pt.pch}, \code{pt.cex} and
      \code{pt.col} in colour mode).  The factory setting defines 5
      styles with black dots, circles, \code{+} crosses, triangles and
      \code{x} crosses.}

  }
}
\seealso{

  \code{\link{eo.setup}}, \code{\link{eo.iso}},
  \code{\link{eo.iso.diff}}, \code{\link{eo.points}},
  \code{\link{eo.legend}}, \code{\link{ucs.par}}, \code{par}

}
\examples{

print(names(ucs.eo()))          # list available parameters

eo.par("col", "lty", "lwd")     # the default styles for iso-lines
eo.par(c("col", "lty", "lwd"))  # works as well

## temporary changes to graphics paramters:
par.save <- eo.par(bw=TRUE, steps=200)
## (e,o) plots use the modified parameters here
eo.par(par.save)		# restore previous values

ucs.library("eo", reload=TRUE)  # reload module for factory defaults

}
\keyword{UCS}
\keyword{iplot}

\eof
% --- Source file: man/eo.points.Rd ---
\name{eo.points}
\alias{eo.points}
\title{Draw Data Set as Point Cloud in (e,o) Plane (eo)}
\description{

  Plot (selected) pair types from a data set as a point cloud in the
  (e,o) plane.  Points can be drawn in any of the styles defined in the
  global defaults (\code{eo.par}), as determined by the \code{style}
  parameter.

}
\usage{

eo.points(ds, style=1, select=NULL, bw=bw, jitter=eo.par("jitter"),
          pch=par("pt.pch"), cex=par("pt.cex"), col=par("pt.col"), ...)

}
\arguments{

  \item{ds}{a data set containing the pair types to be plotted as
    a point cloud}

  \item{style}{an integer specifying the style (shape, size and colour)
    in which points will be drawn.  The number of styles available
    depends on the global parameter settings (\code{eo.par}).  The
    "factory settings" define 5 different styles for points.}

  \item{select}{an optional expression, which is evaluated on the data
    set \code{ds} to select a subset of the pair types for plotting
    (e.g. \code{select=(f <= 10 & b.TP)} to display pair types with
    joint frequency \eqn{f \le 10} that are marked as true positives).}

  \item{bw}{If \code{TRUE}, the points are drawn in B/W mode,
    otherwise in colour mode.  This parameter defaults to the state
    specified with the initial \code{eo.setup} call, but can be
    overridden manually.}

  \item{jitter}{If \code{TRUE}, the coordinates of pair types are
    jittered for the plot, i.e. a small random displacement is added to
    each point so that the point cloud has a more homogeneous
    appearance.  In order to use this option, the data set has to be
    annotated with the \code{add.jitter} function first.  The default
    value is set with \code{eo.par}.}

  \item{pch, cex, col}{The style parameters for points are determined
    automatically from the global settings (\code{eo.par}), according to
    the selected \code{style} and \code{bw} mode.  They can be
    overridden by specifying explicit values in the function call.}

  \item{...}{Any additional parameters are passed through to the
    \code{points} function that draws the point cloud.}

}
\details{

  See the \code{\link{eo.setup}} help page for a description of the
  general procedure used to create (e,o) plots.  This help page also has
  links to other (e,o) plotting functions.  The "factory setting" styles
  are described on the \code{\link{eo.par}} help page.

}
\seealso{

  \code{\link{eo.par}}, \code{\link{eo.setup}}

}
\examples{

## an example can be found on the "eo.setup" help page

}
\keyword{UCS}
\keyword{hplot}
\eof
% --- Source file: man/eo.setup.Rd ---
\name{eo.setup}
\alias{eo.setup}
\alias{eo.close}
\title{Initialise and Finalise an (e,o) Plot (eo)}
\description{

  \code{eo.setup} initialises a new (e,o) plot window, which can then be
  drawn into with calls to \code{eo.iso}, \code{eo.points} and similar
  functions.  The plot has to be finalised with \code{eo.close} before a
  new plot can be generated.

  A detailed explanation of (e,o) plots and their interpretation can be
  found in Section 3.3 of Evert (2004).

}
\usage{

eo.setup(xlim=eo.par("xlim"), ylim=eo.par("ylim"), ds=NULL,
         bw=eo.par("bw"), file=NULL,
         aspect=eo.par("aspect"), log.marks=eo.par("log.marks"),
         cex=eo.par("cex"), ...)

eo.close()

}
\arguments{

  \item{xlim, ylim}{integer vectors of length 2, specifying ranges for
    the e-axis (\code{xlim}) and o-axis (\code{ylim}) in orders of
    magnitude (i.e., base 10 logarithms: -2 corresponds to .01, 0
    corresponds to 1, and 3 corresponds to 1000).  If \code{xlim} and
    \code{ylim} are not given and no default values have been set with
    \code{eo.par}, the \code{ds} parameter has to be specified.  Note
    that (e,o) plots are always drawn in logarithmic scale.}

  \item{ds}{A data set from which suitable ranges for the e-axis and
    o-axis are computed.  The automatically determined values are
    overridden by explicit \code{xlim} and \code{ylim} parameters.}

  \item{bw}{If \code{TRUE}, the (e,o) plot is drawn in B/W mode,
    otherwise in colour mode.  The default value is set with
    \code{eo.par}.}

  \item{file}{a character string giving the name of a PostScript
    file. If specified, the (e,o) plot is saved to \code{file} in EPS
    format rather than displayed on screen.  Note that this file will
    only be written after \code{eo.close} has been called.}

  \item{aspect}{If \code{TRUE}, an aspect ratio of 1:1 is enforced by
    extending the axis ranges as necessary (assuming that the plotting
    region is square).  The default value is set with \code{eo.par}.}

  \item{log.marks}{If \code{TRUE}, tick marks on the axes are labelled
    in logarithmic units, i.e. orders of magnitude.  Otherwise, absolute
    numbers are used.  The default value is set with \code{eo.par}.
    (Recall that (e,o) plots are always drawn in logarithmic scale.)}

  \item{cex}{overall character expansion factor (for tick marks, axis
    labels and legends).  The default value is set with \code{eo.par}.}

  \item{...}{Any additional parameters are passed through to the
    \code{plot} function used to set up the plot region and axes.}

}
\details{
  An (e,o) plot is typically created in four stages:

  \itemize{

    \item Set up the plot with \code{eo.setup}, defining suitable ranges
    for the e-axis.  These ranges and some other state information
    (e.g. whether the plot is drawn in colour or B/W mode) are recorded
    in the global variable \code{.eo.STATE}.

    \item Draw data sets as point clouds with \code{eo.points} and
    iso-lines for GAMs with \code{eo.iso}.  Differences between two
    acceptance regions can be highlighted with \code{eo.iso.diff}.  The
    \code{eo.mark} function can be used to mark individual points with
    circles.

    \item Draw legend boxes in the corners of the plot with
    \code{eo.legend.points}, \code{eo.legend.iso} and
    \code{eo.legend.diff}.
    
    \item Finalise the plot with \code{eo.close}.  When a \code{file}
    argument has been specified in the \code{eo.setup} call, the plot
    will be saved to a PostScript file at this stage.

  }    

  Default values for \code{xlim}, \code{ylim}, \code{bw}, \code{aspect},
  \code{log.marks} and \code{cex} can be set with the \code{eo.par}
  function.  See the \code{eo.par} help page for "factory settings" of
  these parameters, as well as default line and point styles in colour
  and B/W mode.

  Note that (e,o) plots are always drawn in logarithmic scale and tick
  marks are shown for orders of magnitude (full powers of ten).  The
  \code{log.marks} parameter only determines whether the labels on these
  tick marks show linear (.1, 1, 10, 100, \ldots) or logarithmic (-1, 0,
  1, 2, \ldots) values.

}
\references{

  Evert, Stefan (2004). \emph{The Statistics of Word Cooccurrences: Word
    Pairs and Collocations.} PhD Thesis, IMS, University of Stuttgart.

}
\seealso{

  \code{\link{eo.par}}, \code{\link{eo.points}}, \code{\link{eo.iso}},
  \code{\link{eo.iso.diff}}, \code{\link{eo.mark}},
  \code{\link{eo.legend}}

}
\examples{

ucs.library("eo")

## load data set file, add jitter, and reduce to random 10% subset
ds <- add.jitter(read.ds.gz("dickens.ds.gz"))
select <- rbinom(nrow(ds), 1, .1) == 1 
ds <- ds[select,]

## 1) set up new (e,o) plot with suitable axis ranges
eo.setup(ds=ds)  # note that y axis is extend to enforce 1:1 aspect

## 2) add data set as point cloud and three iso-lines
eo.points(ds, style=5, jitter=TRUE)
eo.iso("Poisson.pv", 3, style=1)  # p-value = 1e-3
eo.iso("z.score", 3.09, style=2)  # corresponding one-sided z-score
eo.iso("t.score", 3.09, style=3)  # same as t-score with df=Inf

## 3) add legend boxes in top right (2) and bottom right (3) corner
eo.legend.points(2, "pair type", 5)
eo.legend.iso(3, c("Poisson", "z-score", "t-score"), 1:3)

## 4) finalise the (e,o) plot
eo.close()

}
\keyword{UCS}
\keyword{hplot}
\eof
% --- Source file: man/evaluation.file.Rd ---
\name{evaluation.file}
\alias{evaluation.file}
\title{Evaluation Graphs for Association Measures (plots)}
\description{
  The \code{evaluation.plot} function is often invoked twice with the
  same parameter settings, once for on-screen display, and once for
  saving the plot to a PostScript file.  \code{evaluation.file}
  automates this process, automatically switching between colour mode
  for the screen version and B/W mode for the PostScript version.
}
\usage{
evaluation.file(ds, keys, file, bw=NULL, ...)
}
\arguments{
  \item{ds}{a UCS data set object (passed to \code{evaluation.plot})}
  \item{keys}{a character vector specifying the names of association
    measures to be evaluated (passed to \code{evaluation.plot})}
  \item{file}{a character string giving the name of a file to which the
    PostScript version of the plot will be saved}
  \item{bw}{if \code{TRUE}, both versions will be in B/W;  if
    \code{FALSE}, both versions will be in colour.  If unspecified,
    \code{evaluation.file} switches automatically from colour mode (for
    the screen version) to B/W mode (for the PostScript file), which is
    the most common use.}
}
\details{
  PostScript versions can be suppressed by setting
  \preformatted{
    ucs.par(do.file=FALSE)
  }
  In this case, \code{evaluation.file} will only draw the screen
  versions of the graphs, which is convenient when experimenting and
  while fine-tuning the plots.
}
\seealso{
  \code{\link{evaluation.plot}}, \code{\link{ucs.par}}, and the tutorial
  script \file{tutorial.R} in the \file{script/} directory.
}
\keyword{UCS}
\keyword{hplot}

\eof
% --- Source file: man/evaluation.plot.Rd ---
\name{evaluation.plot}
\alias{evaluation.plot}
\alias{precision.plot}
\alias{recall.plot}
\alias{recall.precision.plot}
\title{Evaluation Graphs for Association Measures (plots)}
\description{
  An implementation of evaluation graphs for the empirical
  evaluation of association measures in terms of precision and recall,
  as described in (Evert, 2004, Ch. 5).   Graphs of precision, recall
  and local precision for n-best lists, as well as precision-by-recall
  graphs are all provided by a single function \code{evaluation.plot}.
}
\usage{
evaluation.plot(ds, keys, tp=ds$b.TP,
                x.min=0, x.max=100, y.min=0, y.max=100,
                x.axis=c("n.best", "proportion", "recall"),
                y.axis=c("precision", "local.precision", "recall"),
                n.first=ucs.par("n.first"), n.step=ucs.par("n.step"),
                cut=NULL, window=400,
                show.baseline=TRUE, show.nbest=NULL, show.npair=NULL,
                conf=FALSE, conf.am=NULL, conf.am2=NULL,
                test=FALSE, test.am1=NULL, test.am2=NULL,
                test.step=ucs.par("test.step"), test.relevant=0,
                usercode=NULL,
                file=NULL, aspect=1, plot.width=6, plot.height=6,
                cex=ucs.par("cex"), lex=ucs.par("lex"), bw=FALSE,
                legend=NULL, bottom.legend=FALSE,
                title=NULL, ...) 
}
\arguments{
  \item{ds}{a UCS data set object, read in from a data set file with
    the \code{\link{read.ds.gz}} function.  \code{ds} must contain
    rankings for the association measures listed in the \code{keys}
    parameter (use \code{\link{add.ranks}} to add such rankings to a
    data set object).}
  \item{keys}{a character vector naming up to 10 association measures to
    be evaluated. Each name may be abbreviated to prefix that must
    be unique within the measures annotated in \code{ds}.
    Use the \code{\link{ds.find.am}} function to obtain a
    list of measures annotated in the data set, and see the \code{ucsam}
    manpage in UCS/Perl for detailed information about the association
    measures supported by the UCS system (with the shell command
    \code{ucsdoc ucsam}).}
  \item{tp}{a logical vector indicating true positives, parallel to the
    rows of the data set \code{ds}.  If \code{tp} is not specified, the
    data set must contain a variable named \code{b.TP} which is used
    instead.}
  \item{x.min, x.max}{the limits of the x-axis in the plot, used to
    \dQuote{zoom in} to an interesting region.  The interpretation of
    the values depends on the \code{x.axis} parameter below.  For
    \code{x.axis="n.best"} (the default case), \code{x.min} and
    \code{x.max} refer to n-best lists.  Otherwise, they refer to
    percentages ranging from 0 to 100.  By default, the full data set is
    shown.}
  \item{y.min, y.max}{the limits of the y-axis in the plot, used to
    \dQuote{zoom in} to an interesting region.  The values are always
    interpreted as percentages, ranging from 0 to 100.  By default,
    \code{y.max} is fitted to the evaluation graphs (unless
    \code{y.axis="recall"}, where \code{y.max} is always set to 100).}
  \item{x.axis}{select variable shown on x-axis.  Available choices are
    the n-best list size \eqn{n} (\code{"n.best"}, the default), the
    same as a proportion of the full data set (\code{"proportion"}), and
    the recall as a percentage (\code{"recall"}).  The latter produces
    precision-by-recall graphs. Unless you are silly enough to specify
    \code{y.axis="recall"} at the same time, that is.}
  \item{y.axis}{select variable shown on x-axis.  Available choices are
    the precision (\code{"precision"}, the default), an estimate for
    local precision (\code{"local.precision"}, see details below), and
    the recall (\code{"recall"}).  All three variables are shown as
    percentages ranging from 0 to 100.}
  \item{n.first}{the smallest n-best list to be evaluated.  Shorter
    n-best lists typically lead to highly unstable evaluation graphs.
    The standard setting is 100, but a higher value may be necessary for
    random sample evaluation (see details below).  If \code{n.first} is
    not specified, the default supplied by \code{\link{ucs.par}} is
    used.}
  \item{n.step}{the step width for n-best lists in the evaluation
    graphs.  Initially, precision and recall are computed for all n-best
    lists, but only every \code{n.step}-th one is plotted, yielding
    graphs that look less jagged and reducing the size of generated
    PostScript files (see the \code{file} parameter below).  If
    \code{n.step} is not specified, the default supplied by
    \code{\link{ucs.par}} is used.}
  \item{cut}{for each association measure, pretend that the data set
    consists only of the \code{cut} highest-ranked candidates according
    to this measure.  This trick can be used to perform an evaluation
    of n-best lists without having to annotate the full data set.  The
    candidates from all relevant n-best lists are combined into a single
    data set file and \code{cut} is set to \eqn{n}.}
  \item{window}{number of candidates to consider when estimating local
    precision (default: 400), i.e. with the option
    \code{y.axis="local"}.  Values below 400 or above 1000 are rarely
    useful.  See below for details.}
  \item{show.baseline}{if \code{TRUE}, show baseline precision as dotted
    horizontal line with label (this is the default).  Not available
    when \code{y.axis="recall"}.}
  \item{show.nbest}{integer vector of n-best lists that will be
    indicated as thin vertical lines in the plot.  When
    \code{x.axis="recall"}, the n-best lists are shown as diagonal
    lines.}
  \item{show.npair}{when \code{x.axis="proportion"}, the total number of
    candidates in \code{ds} is shown in the x-axis label.  Set
    \code{show.npair=NULL} to suppress this, or set it to an integer
    value in order to lie about the number of candidates (rarely
    useful).}
  \item{conf}{if \code{TRUE}, confidence intervals are shown as coloured
    or shaded regions around one or two precision graphs.  In this case,
    the parameter \code{conf.am} must also be specified.  Alternatively,
    \code{conf} can be set to a number indicating the significance level
    to be used for the confidence intervals (default: \eqn{0.05},
    corresponding to 95\% confidence).  See below for details.  Note
    that \code{conf} is only available when \code{y.axis="precision"}.}
  \item{conf.am}{name of the association measure for which confidence
    intervals are displayed (may be abbreviated to a prefix that is
    unique within \code{keys})}
  \item{conf.am2}{optional second association measure, for which
    confidence intervals will also be shown}
  \item{test}{if \code{TRUE}, significance tests are carried out for the
    differences between the evaluation results of two association
    measures, given as \code{test.am1} and \code{test.am2} below.
    Alternatively, \code{test} can be set to a number indicating the
    significance level to be used for the tests (default: \eqn{0.05}).
    n-best lists where the result difference is significant are
    indicated by arrows between the respective evaluation graphs (when
    \code{x.axis="recall"}) or by coloured triangles (otherwise).  See
    details below.  Note that \code{test} is \emph{not} available when
    \code{y.axsis="local"}.}
  \item{test.am1}{the first association measure for significance tests
    (may be abbreviated to a prefix that is unique within \code{keys}).
    Usually, this is the measure that achieves better performance (but
    tests are always two-sided).}
  \item{test.am2}{the second association measure for significance tests
    (may be abbreviated to a prefix that is unique within \code{keys})}
  \item{test.step}{the step width for n-best lists where significance
    tests are carried out, as a multiple of \code{n.step}.  The standard
    setting is 10 since the significance tests are based on the
    computationally expensive \code{fisher.test} functio and
    since the triangles or arrows shown in the plot are fairly large.
    If \code{test.step} is not specified, the default supplied by
    \code{\link{ucs.par}} is used.}
  \item{test.relevant}{a positive number, indicating the estimated
    precision differences that are considered \dQuote{relevant} and that
    are marked by dark triangles or arrows in the plot.  See below for
    details.}
  \item{usercode}{a callback function that is invoked when the plot has
    been completed, but before the legend box is drawn.  This feature is
    mainly used to add something to a plot that is written to a
    PostScript file.  The \code{usercode} function is invoked with
    parameters \code{region=c(x.min,x.max,y.min,y.max)} and \code{pr}, a
    list of precision/recall tables (as returned by
    \code{\link{precision.recall}}) for each of the measures in
    \code{keys}.}
  \item{file}{a character string giving the name of a PostScript file.
    If specified, the evaluation plot will be saved to \code{file}
    rather than displayed on screen.  See \code{\link{evaluation.file}}
    for a function that combines both operations.}
  \item{aspect}{a positive number specifying the desired aspect of the
    plot region (only available for PostScript files).  In the default
    case \code{x.axis="n.best"}, \code{aspect} refers to the absolute
    size of the plot region.  Otherwise, it specifies the size ratio
    between percentage points on the x-axis and the y-axis.  Setting
    \code{aspect} modifies the height of the plot (\code{plot.height}).}
  \item{plot.width, plot.height}{the width and height of a plot that is
    written to a PostScript file, measured in inches.
    \code{plot.height} may be overridden by the \code{aspect} parameter,
    even if it is set explicitly.}
  \item{cex}{character expansion factor for labels, annotations, and
    symbols in the plot (see \code{par} for details).  If \code{cex} is
    not specified, the default supplied by \code{\link{ucs.par}} is
    used.}
  \item{lex}{added to the line widths of evaluation graphs and some
    decorations (note that this is not an expansion factor).  If
    \code{lex} is not specified, the default supplied by
    \code{\link{ucs.par}} is used.}
  \item{bw}{if \code{TRUE}, the evaluation plot is drawn in black and
    white, which is mostly used in conjunction with \code{file} to
    produce figures for articles (defaults to \code{FALSE}).  See below
    for details.}
  \item{legend}{a vector of character strings or expressions, used as
    labels in the legend of the plot (e.g. to show mathematical symbols
    instead of the names of association measures).  Use
    \code{legend=NULL} to suppress the display of a legend box.}
  \item{bottom.legend}{if \code{TRUE}, draw legend box in bottom right
    corner of plot (default is top right corner).}
  \item{title}{a character vector or expression to be used as the main
    title of the plot (optional)}
  \item{...}{any other arguments are set as local graphics parameters
    (using \code{par}) before the evaluation plot is drawn}
}
\details{
  When \code{y.axis="local.precision"}, the evaluation graphs show 
  \bold{local precision}, i.e. an estimate for the density of true
  positives around the n-th rank according to the respective association
  measure.  Local precision is smoothed using a kernel density estimate
  with a Gaussian kernel (from the \code{density} function), based on
  a symmetric window covering approximately \code{window} candidates
  (default: 400).  Consequently, the resulting values do not have a
  clear-cut interpretation and should not be used to evaluate the
  performance of association measures.  They are rather a means of
  exploratory data analysis, helping to visualise the relation between
  association scores and the true positives in a data set (see Evert,
  2004, Sec. 5.2 for an example).

  In order to generalise evaluation results beyond the specific data
  set on which they were obtained, it is necessary to compute confidence
  intervals for the observed precision values and to test whether
  the observed result differences are significant.  See
  (Evert, 2004, Sec. 5.3) for the methods used and the interpretation of
  their results.

  \bold{Confidence intervals} are computed by setting
  \code{conf=TRUE} and selecting an association measure with the
  \code{conf.am} parameter.  The confidence intervals are displayed as a
  coloured or shaded region around the precision graph of this measure
  (confidence intervals are not available for graphs of recall or local
  precision).  The default confidence level of 95\% will rarely need to
  be changed.  Optionally, a second confidence region can be displayed
  for a measure selected with the \code{conf.am2} parameter.

  \bold{Significance tests} for the result differences are activated by
  setting \code{test=TRUE} (not available for graphs of local
  precision).  The evaluation results of two association measures
  (specified with \code{test.am1} and \code{test.am2}) are compared for
  selected n-best lists, and significant differences are marked by
  coloured triangles or arrows (when \code{x.axis="recall"}).  The
  default significance level of \eqn{0.05} will rarely need to be
  changed.  Use the \code{test.step} parameter to control the spacing of
  the triangles or arrows.

  A significant difference indicates that measure A is truly better than
  measure B, rather than just as a coincidence in a single evaluation
  experiment.  Formally, this \dQuote{true performance} can be defined
  as the average precision of a measure, obtained by averaging over many
  similar evaluation experiments.  Thus, a significant difference
  means that the average precision of A is higher than that of B, but it
  does not indicate how great the difference is.  A tiny difference
  (say, of half a percent point) is hardly \bold{relevant} for an
  application, even if there is significant evidence for it.  If the
  \code{test.relevant} parameter is set, the \code{evaluation.plot}
  function attempts to estimate whether there is significant evidence
  for a relevant difference (of at least a many percent points as given
  by the value of \code{test.relevant}), and marks such cases by darker
  triangles or arrows.  This feature should be considered experimental
  and used with caution, as the computation involves many approximations
  and guesses (exact statistical inference for the difference in true
  precision not being available).

  It goes without saying that confidence regions and significance tests
  do not allow evaluation results to be generalised to a different
  extraction task (i.e. another type of cooccurrences or another
  definition of true positives), or even to the same task under
  different conditions (such as a source corpus from a different domain,
  register, time, or a corpus of different size).  The unpredictability
  of the performance of association measures for different extraction
  tasks or under different conditions has been confirmed by various
  evaluation studies.

  Generally, evaluation plots can be drawn in two modes: \bold{colour}
  (\code{bw=FALSE}, the default) or \bold{black and white}
  (\code{bw=TRUE}).  The styles of evaluation graphs are controlled by
  the respective settings in \code{\link{ucs.par}}, while the appearance
  of various other elements is hard-coded in the \code{evaluation.plot}
  function.  In particular, confidence regions are either filled with a
  light background colour (colour mode) or shaded with diagonal lines
  (B/W mode).  The triangles or arrows used to mark significant
  differences are yellow or red (indicating relevance) in colour mode,
  and light grey or dark grey (indicating relevance) in B/W mode.  B/W
  mode is mainly used to produce PostScript files to be included as
  figures in articles, but can also be displayed on-screen for testing
  purposes.

  The \code{evaluation.plot} function supports \bold{evaluation based on
    random samples}, or RSE for short (Evert, 2004, Sec. 5.4).  Missing
  values (\code{NA}) in the \code{tp} vector (or the \code{b.TP}
  variable in \code{ds}) are interpreted as unannotated candidates.  In
  this case, precision, recall and local precision are computed as
  maxmium-likelihood estimates based on the annotated candidates.
  Confidence intervals and significance tests, which should not be
  absent from any RSE, are adjusted accordingly.  A confidence interval
  for the baseline precision is automatically shown (by thin dotted
  lines) when RSE is detected.  Note that n-best lists  (as shown on the
  x-axis) still refer to the full data set, not just to the number of
  annotated candidates.
}
\note{
  The following functions are provided for compatibility with earlier
  versions of UCS/R: \code{precision.plot}, \code{recall.plot}, and
  \code{recall.precision.plot}.  They are simple front-ends to
  \code{evaluation.plot} with the implicit parameter settings
  \code{y.axis="recall"} and \code{y.axis="precision", x.axis="recall"}
  for the latter two.
}
\references{
  Evert, Stefan (2004). \emph{The Statistics of Word Cooccurrences: Word
    Pairs and Collocations.} PhD Thesis, IMS, University of Stuttgart.
}
\seealso{
  \code{\link{ucs.par}}, \code{\link{evaluation.file}},
  \code{\link{read.ds.gz}}, and \code{\link{precision.recall}}.
  The \R script \file{tutorial.R} in the \file{script/} directory
  provides a gentle introduction to the wide range of possibilities
  offered by the \code{evaluation.plot} function.
}
\keyword{UCS}
\keyword{hplot}

\eof
% --- Source file: man/evaluation.table.Rd ---
\name{evaluation.table}
\alias{evaluation.table}
\title{Precision/Recall Tables for the Evaluation of Association Measures (base)}
\description{
  A simple text-mode version of the precision/recall-based evaluation
  provided by the \code{plots} module.  Returns a table of precision or
  recall values for a selected range of association measures on selected
  n-best lists.
  \bold{This is a preliminary version of the function - both interface
    and functionality may change in future releases.}
}
\usage{
evaluation.table(ds, keys, n, tp=ds$b.TP, recall=FALSE)
}
\arguments{
  \item{ds}{a UCS data set object, read in from a data set file with
    the \code{\link{read.ds.gz}} function.  \code{ds} must contain
    rankings for the association measures listed in the \code{keys}
    parameter (use \code{\link{add.ranks}} to add such rankings to a
    data set object).}
  \item{keys}{a character vector specifying the names of association measures to
    be evaluated. Each name may be abbreviated to prefix that must be
    unique within the measures annotated in \code{ds}.
    Use the \code{\link{ds.find.am}} function to obtain a
    list of measures annotated in the data set, and see the \code{ucsam}
    manpage in UCS/Perl for detailed information about the association
    measures supported by the UCS system (with the shell command
    \code{ucsdoc ucsam}).}
  \item{n}{a vector of n-best sizes for which precision or recall values
    are computed}
  \item{tp}{a logical vector indicating true positives, parallel to the
    rows of the data set \code{ds}.  If \code{tp} is not specified, the
    data set must contain a variable named \code{b.TP} which is used
    instead.}
  \item{recall}{if \code{TRUE}, returns table of recall values,
    otherwise table of precision values (default)}
}
\value{
  A data frame whose rows correspond to n-best lists.  In addition to
  the column labelled \code{n}, which gives the n-best lists for which
  the evaluation was carried out, there is one column for each
  selected association measure.  The column is labelled with the name of
  the measure and lists the corresponding precision or recall values,
  depending on the \code{recall} parameter.
}
\seealso{
  \code{\link{evaluation.plot}}, \code{\link{precision.recall}}
}
\keyword{UCS}
\eof
% --- Source file: man/fzm.Rd ---
\name{fzm}
\alias{fzm}
\title{The Finite Zipf-Mandelbrot LNRE Model (fzm)}
\description{
  Object constructor for a finite Zipf-Mandelbrot (fZM) LNRE model with
  parameters \eqn{\alpha}, \eqn{A} and \eqn{B} (Evert, 2004a).  Either
  the parameters are specified explicitly, or one or more of them can be
  estimated from an observed frequency spectrum.
}
\synopsis{
fzm(alpha=NULL, A=NULL, B=NULL, N=NULL, V=NULL, spc=NULL, m.max=15, stepmax=10, debug=FALSE)
}
\usage{
fzm(alpha, A, B)

fzm(alpha, A, N, V)

fzm(alpha, N, V, spc, m.max=15, stepmax=10, debug=FALSE)

fzm(N, V, spc, m.max=15, stepmax=10, debug=FALSE)
}
\arguments{
  \item{alpha}{a number in the range \eqn{(0,1)}, the shape parameter
    \eqn{\alpha} of the fZM model.  \code{alpha} can automatically be
    estimated from \code{N}, \code{V}, and \code{spc}.}
  \item{A}{a small positive number \eqn{A \ll 1}{A << 1}, the parameter
    \eqn{A} of the fZM model. \code{A} can automatically be estimated
    from \code{N}, \code{V}, and \code{spc}.}
  \item{B}{a large positive number \eqn{B \gg 1}{B >> 1}, the parameter
    \eqn{B} of the fZM model. \code{B} can automatically be estimated
    from \code{N} and \code{V}.}
  \item{N}{the sample size, i.e. number of observed tokens}
  \item{V}{the vocabulary size, i.e. the number of observed types}
  \item{spc}{a vector of non-negative integers representing the class
    sizes \eqn{V_m} of the observed frequency spectrum.  The vector is
    usually read from a file in \code{lexstats} format with the
    \code{\link{read.spectrum}} function.}
  \item{m.max}{the number of ranks from \code{spc} that will be used to
    estimate the \eqn{\alpha} parameter}
  \item{stepmax}{maximal step size of the \code{nlm} function used for
    parameter estimation.  It should not be necessary to change the
    default value.}
  \item{debug}{if \code{TRUE}, print debugging information during the
    parameter estimation process.  This feature can be useful to find
    out why parameter estimation fails.}
}
\value{
  An object of class \code{"fzm"} with the following components:
  \item{alpha}{value of the \eqn{\alpha} parameter}
  \item{A}{value of the \eqn{A} parameter}
  \item{B}{value of the \eqn{B} parameter}
  \item{C}{value of the normalisation constant \eqn{C}}
  \item{C}{population size \eqn{S} predicted by the model}
  \item{N}{number of observed tokens (if specified)}
  \item{V}{number of observed types (if specified)}
  \item{spc}{observed frequency spectrum (if specified)}
  This object \code{print}s a short summary, including the population
  size \eqn{S} and a comparison of the first ranks of the observed and
  expected frequency spectrum (if available).
}
\details{
  The fZM model with parameters \eqn{\alpha \in (0,1)} and \eqn{C > 0} is
  defined by the type density function
  \deqn{g(\pi) := C\cdot \pi^{-\alpha-1}}{%
    g(p) := C * p^(-alpha - 1)}
  for \eqn{A\leq \pi\leq B}{A <= p <= B}.  The normalisation constant
  \eqn{C} is determined from the other parameters by the condition
  \deqn{\int_A^B \pi\cdot g(\pi) d\pi = 1}{%
    integral_A^B p * g(p) dp = 1}

  The parameters \eqn{\alpha} and \eqn{A} are estimated simultaneously
  by nonlinear minimisation (\code{nlm}) of a multinomial chi-squared
  statistic for the observed against the expected frequency spectrum.
  Note that this is different from the multivariate chi-squared test
  used to measure the goodness-of-fit of the final model (Baayen, 2001,
  Sec. 3.3).

  See Evert (2004, Ch. 4) for further mathematical details, especially
  concerning the expected vocabulary size, frequency spectrum and
  conditional parameter distribution, as well as their variances.
}
\references{
  Baayen, R. Harald (2001). \emph{Word Frequency Distributions.} Kluwer,
  Dordrecht.

  Evert, Stefan (2004). \emph{The Statistics of Word Cooccurrences: Word
    Pairs and Collocations.} PhD Thesis, IMS, University of Stuttgart.

  Evert, Stefan (2004a). A simple LNRE model for random character
  sequences. In \emph{Proceedings of JADT 2004}, Louvain-la-Neuve,
  Belgium, pages 411--422.
}
\seealso{
  \code{\link{zm}}, \code{\link{EV}}, \code{\link{EVm}},
  \code{\link{VV}}, \code{\link{VVm}},
  \code{\link{write.lexstats}}, \code{\link{lnre.goodness.of.fit}},
  \code{\link{read.spectrum}}, and \code{\link{spectrum.plot}}
}
\keyword{UCS}
\keyword{models}
\keyword{LNRE}

\eof
% --- Source file: man/gam.helpers.Rd ---
\name{gam.helpers}
\alias{gam.helpers}
\alias{gam.yates}
\alias{gam.yates.inv}
\alias{b.star}
\alias{b.norm}
\alias{e.bar}
\alias{signed.sqrt}
\title{Helper Functions for GAM Equations (gam)}
\description{
  \code{gam.yates} and \code{gam.yates.inv} implement an invertible
  version of the discounting function used by Yates' correction.
  \code{signed.sqrt}, \code{b.star}, \code{b.norm} and \code{e.bar} are
  standard abbreviations used in the definition of generalised
  association measures in terms of ebo-coordinates.
}
\usage{
  gam.yates(d)
  gam.yates.inv(d.corr)

  signed.sqrt(x)

  b.star(b)
  b.norm(b)
  e.bar(e, b, N)
}
\arguments{
  \item{d}{difference between observed and expected frequency, to which
    the generalised Yates' correction is applied}
  \item{d.corr}{difference between observed and expected frequency with
    generalised Yates' correction applied, from which the original
    difference can uniquely be reconstructed}
  \item{x}{a vector of positive or negative real numbers}
  \item{b}{a vector of \emph{balance} (\eqn{b}) values in the ebo coordinate system}
  \item{e}{a vector of \emph{expectation} (\eqn{e}) values in the ebo
    coordinate system}
  \item{N}{sample size \eqn{N}}
}
\value{
  all functions return a vector of real numbers
}
\details{
  The standard discounting function for Yates' correction is \eqn{d^* :=
    d - 1/2}{d* := d - 1/2} for \eqn{d \ge 0} and \eqn{d^* := d +
    1/2}{d* := d + 1/2} for \eqn{d < 0},
  where \eqn{d} is the difference between observed and expected
  frequency. This definition does not lead to a continuous and
  invertible function of \eqn{d}, so a GAM with Yates' correction
  applied does not satisfy the soundness conditions.  The generalised
  Yates' correction implemented by \code{gam.yates} and
  \code{gam.yates.inv} is a monotonic (and hence invertible) function that
  is identical to the standard discounting function for \eqn{|d| \ge
    1}{d >= 1} and uses linear interpolation for \eqn{-1 < d < 1}.
 
  The functions \code{signed.sqrt}, \code{b.star}, \code{b.norm} and
  \code{e.bar} compute the standard abbreviation \eqn{\pm\sqrt{x}}{+/-
    sqrt(x)}, \eqn{b^*}{b*}, \eqn{\|b\|}{||b||} and
  \eqn{\bar{e}}{\bar{e}} (``e bar'') used by Evert (2004) for the
  definition of GAMs in terms of ebo-coordinates.
}
\references{
  Evert, Stefan (2004). \emph{The Statistics of Word Cooccurrences: Word
    Pairs and Collocations.} PhD Thesis, IMS, University of Stuttgart.
}
\examples{
d <- runif(20, -2, 2)
d.corr <- gam.yates(d)
all(d == gam.yates.inv(d.corr))

signed.sqrt(-4:4)
}
\keyword{UCS}
\keyword{GAM}
\keyword{math}
\eof
% --- Source file: man/gam.iso.Rd ---
\name{gam.iso}
\alias{gam.iso}
\title{Compute Iso-Surfaces for GAMs (gam)}
\description{
  Computes iso-surfaces for a generalised association measure (GAM)
  in standard or ebo-coordinates.
}
\usage{
  gam.iso(name, gamma, f1, f2, N, bsearch.min=NULL, bsearch.max=NULL)
  gam.iso(name, gamme, e, b=1, N=1e6, bsearch.min=NULL, bsearch.max=NULL)
}
\arguments{
  \item{name}{name of a generalised association measure (GAM)}
  \item{gamma}{a numerical constant that determines the desired
    iso-surface \eqn{\{g = \gamma\}}}
  \item{f1, f2, N}{numerical vectors specifying the \code{f1} and
    \code{f2} coordinates of points in the standard coordinate space, as
    well as the sample size \code{N}}
  \item{e, b}{numerical vectors specifying the \code{e} and \code{b}
    coordinates of points in the ebo-coordinate space (if the
    \emph{balance} \eqn{b} is not specified, it defaults to \code{1})}
  \item{N}{optional numerical vector specifying the sample size \eqn{N}
    when computing iso-surfaces for a GAM that is not size-invariant in
    ebo-coordinates (defaults to \code{1e6})}
  \item{bsearch.min}{initial lower boundary for binary search algorithm,
    when no explicit equation for the iso-surface is available}
  \item{bsearch.max}{initial upper boundary for the binary search algorithm}
}
\value{
  a vector of real numbers representing the \code{f} or \code{o}
  coordinates of the respective iso-surface; these are the values of
  \code{f} or \code{o} that solve the implicit equation \eqn{\{g =
    \gamma\}} for the specified values of \code{f1, f2, N} or \code{e, b}
  (and \code{N}); this vector may contain missing values (\code{NA}) for
  points where no solution is found (see "Details" for more information)
}
\details{
  Note that all function arguments except for \code{name} must be passed
  explicitly by name in order to distinguish the two operating modes of
  \code{gam.iso} (standard vs. ebo-coordinates).
  
  When ebo-coordinates are used, the argument \code{N} (\emph{sample
    size}) can safely be omitted for any size-invariant GAM (in
  ebo-coordinates).  For other GAMs, a default value of \code{1e6} will
  be used, corresponding to the typical size of a co-occurrence data
  set.  The argument \code{b} (\emph{balance}) can be omitted for any
  central GAMs.  Otherwise, it defaults to a value of \code{1},
  corresponding to the centralized version of the respective GAM.

  Use \code{gamma.nbest} to compute a suitable \eqn{\gamma} values for
  n-best surfaces.

  When no explicit equation for the iso-surface of a GAM is available,
  the \code{gam.iso} function uses a binary search algorithm to solve
  the implicit equation \eqn{\{g = \gamma\}}.  Since some GAMs are only
  defined for valid frequency signatures (where all four cells of the
  contingency table are non-negative), the binary search for the
  \code{o} coordinate is confined to the range from \eqn{0} to
  \eqn{\min\{f_1, f_2\}}.  When no solution can be found in this range,
  \code{gam.iso} returns \code{NA} for the corresponding points.  For
  GAMs where it is safe to search a larger range (notably
  \code{Poisson.pv} and \code{log.likelihood}), the boundaries of the
  search interval can be adjusted with the \code{bsearch.min} and
  \code{bsearch.max} parameters.  Note that most other GAMs have
  explicit iso-equations, so these parameters are rarely needed.
}
\seealso{
  \code{\link{gam.score}}, \code{\link{builtin.gams}}, \code{\link{gamma.nbest}}
}
\examples{
e <- 10^seq(-2, 1, .1)		# compute iso-line on logarithmic scale
o <- gam.iso("t.score", 2, e=e)

x <- 10^seq(0, 2, .1)		# compute iso-surface over rectangular grid
g <- expand.grid(f1=x, f2=x)
g$f <- gam.iso("t.score", 2, f1=g$f1, f2=g$f2, N=1000)
library(lattice)
wireframe(f ~ f1 * f2, log(g)) 
}
\keyword{UCS}
\keyword{GAM}
\keyword{math}
\eof
% --- Source file: man/gam.score.Rd ---
\name{gam.score}
\alias{gam.score}
\title{Compute GAM Scores in Standard or EBO-Coordinates (gam)}
\description{
  Computes scores of a generalised association measure (GAM)
  in standard or ebo-coordinates.
}
\usage{
  gam.score(name, f, f1, f2, N)
  gam.score(name, o, e, b=1, N=1e6)
}
\arguments{
  \item{name}{name of a generalised association measure (GAM)}
  \item{f, f1, f2, N}{numerical vectors specifying the (generalised)
    frequency signatures of candidates}
  \item{o, e, b}{numerical vectors specifying the ebo-coordinates of
    candidates (if the \emph{balance} \eqn{b} is not specified, it
    defaults to \code{1})}
  \item{N}{optional numerical vector specifying the sample size \eqn{N}
    when computing scores of a GAM that is not size-invariant in
    ebo-coordinates (defaults to \code{1e6})}
}
\value{
  a vector of real numbers representing generalised association scores
}
\details{
  Note that all function arguments except for \code{name} must be passed
  explicitly by name in order to distinguish the two operating modes of
  \code{gam.score} (standard vs. ebo-coordinates).
  
  The components of the generalised frequency signature \code{(f, f1, f2,
    N)} can be arbitrary positive real numbers.

  When ebo-coordinates are used, the argument \code{N} (\emph{sample
    size}) can safely be omitted for any size-invariant GAM (in
  ebo-coordinates).  For other GAMs, a default value of \code{1e6} will
  be used, corresponding to the typical size of a co-occurrence data
  set.  The argument \code{b} (\emph{balance}) can be omitted for any
  central GAMs.  Otherwise, it defaults to a value of \code{1},
  corresponding to the centralized version of the respective GAM.
  
  The \code{gam.score} function automatically converts between standard
  and ebo-coordinates, depending on the requirements of the GAM
  implementation.
}
\seealso{
  \code{\link{add.gams}}, \code{\link{gam.iso}},
  \code{\link{builtin.gams}}
}
\examples{
gam.score("t.score", f=1:10, f1=(1:10)*5, f2=100, N=1000)

gam.score("t.score", o=1:10, e=(1:10)/2)
}
\keyword{UCS}
\keyword{GAM}
\keyword{math}
\eof
% --- Source file: man/gamma.nbest.Rd ---
\name{gamma.nbest}
\alias{gamma.nbest}
\title{Compute Gamma Threshold for N-Best Acceptance Region (gam)}
\description{
  Computes a suitable value of \eqn{\gamma} such that the acceptance
  region \eqn{\{g \ge \gamma\}} contains exactly \eqn{n} candidates
  from a given data set.
}
\usage{
  gamma.nbest(ds, name, n, jitter=FALSE)
}
\arguments{
  \item{ds}{a UCS data set object}
  \item{name}{name of a generalised association measure (GAM)}
  \item{n}{an integer, specifying the number of candidates to be
    included in the acceptance region}
  \item{jitter}{if \code{TRUE}, random jitter is added to the
    coordinates of candidates for computation of the n-best threshold}
}
\value{
  a real number specifying a suitable threshold \eqn{\gamma}, i.e.
  the data set \code{ds} contains exactly \code{n} candidates with
  a GAM score \eqn{g \ge \gamma} (for the specified measure \code{name})
}
\details{
  When \code{jitter=TRUE}, the data set \code{ds} must contain jitter
  vectors stored in special variables.  Such jitter variables can easily
  be added with the \code{add.jitter} function.
}
\seealso{
  \code{\link{add.jitter}}, \code{\link{gam.score}},
  \code{\link{add.gams}}, \code{\link{gam.iso}}, \code{\link{builtin.gams}}
}
\examples{
e <- 10^seq(-2, 1, .1)		# 100-best iso-line for UCS data set ds
gamma <- gamma.nbest(ds, "t.score", 100)
o <- gam.iso("t.score", gamma, e=e)
}
\keyword{UCS}
\keyword{GAM}
\keyword{math}
\eof
% --- Source file: man/iaa.kappa.Rd ---
\name{iaa.kappa}
\alias{iaa.kappa}
\title{Inter-Annotator Agreement: Cohen's Kappa (iaa)}
\description{
  Compute the kappa statistic (Cohen, 1960) as a measure of
  intercoder agreement on a binary variable between two annotators,
  as well as a confidence interval according to Fleiss, Cohen &
  Everitt (1969).  The data can either be given in the form of a
  \eqn{2\times 2}{2-by-2} contingency table or as two parallel
  annotation vectors.
}
\usage{
iaa.kappa(x, y=NULL, conf.level=0.95)
}
\arguments{
  \item{x}{either a \eqn{2\times 2}{2-by-2} contingency table in matrix
    form, or a vector of logicals}
  \item{y}{a vector of logicals; ignored if \code{x} is a matrix}
  \item{conf.level}{confidence level of the returned confidence
    interval (default: \eqn{0.95}, corresponding to 95\% confidence)}
}
\value{
  A data frame with a single row and the following variables:
  \item{kappa}{sample estimate for the kappa statistic}
  \item{sd}{sample estimate for the standard deviation of the kappa
    statistic}
  \item{kappa.min, kappa.max}{two-sided asymptotic confidence interval
    for the \dQuote{true} kappa, based on normal approximation with
    estimated variance}
  The single-row data frame was chosen as a return structure because it
  \code{print}s nicely, and results from different comparisons can
  easily be combined with \code{rbind}.
}
\references{
  Cohen, Jacob (1960). A coefficient of agreement for nominal scales.
  \emph{Educational and Psychological Measurement}, \bold{20},
  37--46.

  Fleiss, Joseph L.; Cohen, Jacob; Everitt, B. S. (1969). Large sample
  standard errors of kappa and weighted kappa. \emph{Psychological
    Bulletin}, \bold{72}(5), 323--327.
}
\seealso{
  \code{\link{iaa.pta}}
}
\examples{
## kappa should be close to zero for random codings
p <- 0.1			# proportion of true positives
x <- runif(1000) < p		# 1000 candidates annotated randomly
y <- runif(1000) < p
iaa.kappa(x, y)
}
\keyword{UCS}
\keyword{htest}

\eof
% --- Source file: man/iaa.pta.Rd ---
\name{iaa.pta}
\alias{iaa.pta.conservative}
\alias{iaa.pta.homogeneous}
\alias{iaa.pta}
\title{Inter-Annotator Agreement: Estimates for the Proportion of True
  Agreement (iaa)}
\description{
  Compute confidence interval estimates for the proportion of true 
  agreement between two annotators on a binary variable, as described by
  Krenn, Evert & Zinsmeister (2004).  \code{iaa.pta.conservative}
  computes a conservative estimate that is rarely useful, while
  \code{iaa.pta.homogeneous} relies on additional assumptions.
  The data can either be given in the form of a \eqn{2\times 2}{2-by-2}
  contingency table or as two parallel annotation vectors.
}
\usage{
iaa.pta.conservative(x, y=NULL, conf.level=0.95, debug=FALSE)

iaa.pta.homogeneous(x, y=NULL, conf.level=0.95, debug=FALSE)
}
\arguments{
  \item{x}{either a \eqn{2\times 2}{2-by-2} contingency table in matrix
    form, or a vector of logicals}
  \item{y}{a vector of logicals; ignored if \code{x} is a matrix}
  \item{conf.level}{confidence level of the returned confidence
    interval (default: \eqn{0.95}, corresponding to 95\% confidence)}
  \item{debug}{if \code{TRUE}, show which divisions of the data
    are considered when computing the confidence interval
    (see Krenn, Evert & Zinsmeister, 2004)}
}
\value{
  A numeric vector giving the lower and upper bound of a confidence
  interval for the proportion of true agreement (both in the range
  \eqn{[0,1]}).
}
\details{
  This approach to measuring intercoder agreement is based on the
  assumption that the observed \bold{surface agreement} in the data can
  be divided into \bold{true agreement} (i.e. candidates where both
  annotators make the same choice \emph{for the same reasons}) and
  \bold{chance agreement} (i.e. candidates on which the annotators agree
  purely by coincidence).  The goal is to estimate the proportion of
  candidates for which there is true agreement between the annotators,
  referred to as PTA.

  The two functions differ in how they compute this estimate.
  \code{iaa.pta.conservative} considers all possible divisions of the
  observed data into true and chance agreement, leading to a
  conservative confidence interval.  This interval is almost always too
  large to be of any practical value.

  \code{iaa.pta.homogeneous} makes the additional assumption that the
  average proportion of true positives is the same for the part of the
  data where the annotators reach true agreement and for the part where
  they agree only by chance.  Note that there is no \emph{a priori}
  reason why this should be the case.  Interestingly, the confidence
  intervals obtained in this way for the PTA correspond closely to those
  for Cohen's kappa statistic (\code{\link{iaa.kappa}}).
}
\note{
  \code{iaa.pta.conservative} is a computationally expensive operation
  based on Fisher's exact test.  (It doesn't use \code{fisher.test},
  though.  If it did, it would be even slower than it is now.)  In most
  circumstances, you will want to use \code{iaa.pta.homogeneous} instead.
}
\references{
  Krenn, Brigitte; Evert, Stefan; Zinsmeister, Heike (2004). Determining
  intercoder agreement for a collocation identification task.  In
  preparation.
}
\seealso{
  \code{\link{iaa.kappa}}
}
\examples{
## how well do the confidence intervals match the true PTA?
true.agreement <- 700		# 700 cases of true agreement
chance <- 300			# 300 cases where annotations are independent
p <- 0.1			# average proportion of true positives
z <- runif(true.agreement) < p  # candidates with true agreement
x.r <- runif(chance) < p	# randomly annotated candidates
y.r <- runif(chance) < p
x <- c(z, x.r)
y <- c(z, y.r)
cat("True PTA =", true.agreement / (true.agreement + chance), "\n")
iaa.pta.conservative(x, y)	# conservative estimate
iaa.pta.homogeneous(x, y)	# estimate with homogeneity assumption
}
\keyword{UCS}
\keyword{htest}

\eof
% --- Source file: man/lnre.goodness.of.fit.Rd ---
\name{lnre.goodness.of.fit}
\alias{lnre.goodness.of.fit}
\title{Perform Goodness-of-Fit Evaluation of LNRE Model}
\description{
  Evaluate the goodness-of-fit of a LNRE model with a
  multivariate chi-squared test (Baayen, 2001, Sec. 3.3).
}
\usage{
lnre.goodness.of.fit(model, m.max=15)
}
\arguments{
  \item{model}{an object representing a LNRE model whose parameters have
    been estimated from observed word frequency data.  Currently, the
    Zipf-Mandelbrot (ZM, class \code{"zm"}) and the finite
    Zipf-Mandelbrot (fZM, class \code{"fzm"}) models are
    supported.}
  \item{m.max}{highest frequency rank to be included in the evaluation
    (limited by the number of ranks stored in the \code{model} object).}
}
\value{
  A data frame with one row and three columns:
  \item{X2}{the value of the multi-variate \eqn{\chi^2} test statistic}
  \item{df}{the degrees of freedom of the approximate \eqn{\chi^2}
    distribution of the test statistic under the null hypothesis}
  \item{p}{the p-value for the test}
}
\details{
  This function performs a multivariate chi-squared test to evaluate the
  goodness-of-fit of an LNRE model (Baayen 2001, p. 119-122).
  
  All LNRE models that follow the UCS/R conventions are supported.
  In particular, they must specify the number of parameters estimated
  from the observed data (in the \code{n.param} component), and they
  must provide appropriate implementations of the \code{EV}, \code{EVm},
  and \code{VV} methods.  Currently available LNRE models are objects of class
  \code{"zm"} or \code{"fzm"}.  The \code{model} object must include observed
  frequency data (in components \code{N}, \code{V}, and \code{spc}),
  which is usually achieved by estimating the model parameters from the
  observed frequency spectrum.
}
\references{
  Baayen, R. Harald (2001). \emph{Word Frequency Distributions.} Kluwer,
  Dordrecht.
}
\seealso{
  \code{\link{zm}}, \code{\link{fzm}}
}
\keyword{UCS}
\keyword{models}
\keyword{LNRE}

\eof
% --- Source file: man/order.by.am.Rd ---
\name{order.by.am}
\alias{order.by.am}
\title{Sort Rows of a Data Set by Association Scores (base)}
\description{
  Sort the rows of a data set according to the annotated scores of an
  association measure (in descending order).  Ties in the ordering are
  broken randomly by default, using the \code{random} association
  measure to yield a reproducible ordering.
}
\usage{
order.by.am(ds, am, randomise=TRUE)
}
\arguments{
  \item{ds}{a UCS data set}
  \item{am}{a character string giving the name of a single association
    measure}
  \item{randomise}{if \code{TRUE}, ties in the ordering are broken
    randomly (default).  Otherwise, the tied rows are arranged according
    to their \code{id} values.  See below for details.
}
\value{
  an integer vector of row numbers, which can be used as a row index for
  the data set object
}
\details{
  With \code{randomise=TRUE}, the data set must contain a variable named
  \code{am.random}, which is used to break ties in the ordering.
  Otherwise, tied rows are arranged according to their ID values, and
  the corresponding \code{id} variable must be annotated in the data set.

  The \code{random} association measure is used for breaking ties
  (rather than random numbers generated on the fly) in order to
  ensure that the ordering is reproducible.  If this measure has not
  been annotated in a data set file, you can easily add the required
  variable to a data set \code{ds} with the command
  \preformatted{
    ds$am.random <- runif(nrow(ds))
  }
  You should probably use \code{set.seed} to ensure a reproducible ordering.
}
\seealso{
  \code{\link{read.ds.gz}}, \code{\link{add.ranks}}
}
\keyword{UCS}

\eof
% --- Source file: man/precision.recall.Rd ---
\name{precision.recall}
\alias{precision.recall}
\title{Compute Precision and Recall for N-Best Lists (base)}
\description{
  Computes precision and recall of n-best lists for a UCS data set
  annotated with true positives and rankings (based on association
  scores). This function forms the basis for the evaluation graphs in
  the \code{plots} packages.
}
\usage{
precision.recall(ds, am, tp=ds$b.TP, step=1, first=1, cut=0, window=0)
}
\arguments{
  \item{ds}{a UCS data set object}
  \item{am}{a character string giving the name of an association measure.
    The corresponding ranking must be annotated in the data set (usually
    with the \code{\link{add.ranks}} function).}
  \item{tp}{a logical vector, which must be parallel to the rows of the
    data set.  \code{TRUE} values indicate true positives (see details
    below for the use of missing values).  If \code{tp} is omitted, the
    data set must contain a Boolean variable \code{b.TP} which is used
    instead.}
  \item{step}{step width for n-best lists considered, i.e. precision and
    recall are computed for every \code{step}-th value of n only
    (default: 1)}
  \item{first}{smallest n-best list for which precision and recall are
    computed (default: 1)}
  \item{cut}{pretend that data set consists only of the first \code{cut}
    rows in the ranking, i.e. treat \code{cut}-best list as full data
    set (for percentage and recall).}
  \item{window}{if specified, local precision is estimated, considering
    a window of approximately the given size around each value of n
    (uses the \code{density} function for smoothing).  Useful window
    sizes range from 400 to 1000.}
}
\value{
  An invisible data frame with rows corresponding to n-best lists and
  the following variables:
  \item{n}{the number of candidates in the n-best list}
  \item{perc}{the same as a percentage of the full data set (or the
    \code{cut} highest-ranking candidates if specified)}
  \item{tp}{the number of true positives in the n-best list}
  \item{fp}{the number of false positives in the n-best list}
  \item{precision}{the precision of the n-best list, i.e. the number of
    TPs divided by n}
  \item{recall}{the recall of the n-best list, i.e. the number of TPs
    divided by the total number of TPs in the data set}
  \item{lp}{if \code{window} is specified, an estimate for the \emph{local
      precision}, i.e. the density of TPs in the vicinity of the n-th
    rank.  Averages over a symmetric window of approximately the
    specified total size by convolution with a Gaussian kernel (using
    the \code{density} function).}
}
\details{
  The \code{precision.recall} function supports evaluation based on
  random samples (cf. Evert, 2004, Sec. 5.4).  Any \code{NA} values in
  the \code{tp} parameter (or the \code{b.TP} variable) are interpreted
  as unannotated candidates.  Precision and recall values are computed
  from the annotated candidates only (as are the \code{tp}, \code{fp},
  and \code{lp} variables in the returned data frame).  For a random
  sample evaluation, confidence intervals should always be supplied with
  the raw precision values, and result differences should be tested for
  significance.  Such tests are implemented by the
  \code{\link{evaluation.plot}} function, for instance.
}
\references{
  Evert, Stefan (2004). \emph{The Statistics of Word Cooccurrences: Word
    Pairs and Collocations.} PhD Thesis, IMS, University of Stuttgart.
}
\seealso{
  \code{\link{add.ranks}}, \code{\link{read.ds.gz}},
  \code{\link{evaluation.plot}}
}
\keyword{UCS}
\keyword{univar}

\eof
% --- Source file: man/read.ds.gz.Rd ---
\name{read.ds.gz}
\alias{read.ds.gz}
\title{Load UCS data set file (base)}
\description{
  Load a UCS data set file, which is uncompressed on the fly if necessary.
}
\usage{
read.ds.gz(filename)
}
\arguments{
  \item{filename}{name, partial or full path of the data set file to be
    loaded.}
}
\value{
  A data frame with column names (i.e. variables) corresponding to those
  in the data set file.  \code{l1} and \code{l2} are read as character
  vectors, all other string variables (\code{f.*}) are converted into
  factors, and Boolean variables (\code{b.*}) are converted into
  logicals.

  Any comments and global variables in the file header are discarded.
}
\details{
  When the specified file is not found in the current directory, it is
  automatically searched in the standard UCS data library (the
  \file{DataSet/} directory and its subdirectories).  Should there be
  multiple matches, a warning is issued and the first match is used.
  You may specify partial paths to identify the desired file unambiguously
  (e.g. \code{"Distrib/dickens.ds.gz"}).  The automatic search facility
  is suppressed when \code{filename} is an explicit absolute or relative
  path (starting with \code{/} or \code{./}).

  \code{gzip}-compressed data set files, whose name must end in
  \code{.gz}, are automagically decompressed.
}
\examples{
## load GLAW data set from UCS distribution
GLAW <- read.ds.gz("glaw.ds.gz")
}
\keyword{UCS}


\eof
% --- Source file: man/read.spectrum.Rd ---
\name{read.spectrum}
\alias{read.spectrum}
\title{Read Frequency Spectrum File (lexstats)}
\description{
  Read a word frequency spectrum from a \code{.spc} file
  in \code{lexstats} format (see Baayen, 2001).  Returns spectrum as
  integer vector, possibly including zeroes, whose \eqn{m}-th element
  gives the number of types \eqn{V_m} with frequency rank \eqn{m}.
  Also computes sample size \eqn{N} and vocabulary size \eqn{V}.
}
\usage{
read.spectrum(file, m.max=Inf, expected=FALSE)
}
\arguments{
  \item{file}{a character string giving the name of a frequency spectrum
    file in \code{lexstats} format (usually with the extension
    \code{.spc})}
  \item{m.max}{maximum length of frequency spectrum, i.e. frequency
    ranks \eqn{m > m_{\max}}{m > m.max} are discarded.  Setting
    \code{m.max} is a good idea if there are high-frequency types, so
    that the spectrum is sparse.  For most applications, only the first
    10 to 100 ranks are of interest.}
  \item{expected}{if \code{TRUE}, reads expected class sizes (in the
    \code{EVm} column) rather than the observed ones (in the \code{Vm}
    column).  This is only possible when the \code{.spc} file was
    generated by a LNRE model, of course.}
}
\value{
  A list with the following components:
  \item{spc}{an integer vector containing the class sizes \eqn{V_m}}
  \item{N}{the sample size computed from the spectrum}
  \item{V}{the vocabulary size computed from the spectrum}
}
\references{
  Baayen, R. Harald (2001). \emph{Word Frequency Distributions.} Kluwer,
  Dordrecht.
}
\seealso{
  \code{\link{spectrum.plot}}, \code{\link{zm}}, \code{\link{fzm}}
}
\keyword{UCS}
\keyword{LNRE}

\eof
% --- Source file: man/spectrum.plot.Rd ---
\name{spectrum.plot}
\alias{spectrum.plot}
\title{Comparative Plot of Word Frequency Spectra (lexstats)}
\description{
  Comparative plot of up to five word frequency spectra (see Baayen,
  2001), either as a side-by-side barplot or as points and lines on a
  logarithmic scale.
}
\usage{
spectrum.plot(spc, m.max=Inf, log=FALSE, y.min=100, y.max=0,
              xlab="m", ylab="V_m / E[V_m]",
              legend=NULL,
              pch=c(1, 3, 15, 2, 20),
              lwd=1,
              lty=c("solid", "dashed", "dotdash", "dotted", "twodash"),
              col=if (log) c("black") else c("black", "grey50", ...))
}
\arguments{
  \item{spc}{a list containing up to five frequency spectrum vectors.
    Such spectrum vectors can be read in from a file in \code{lexstats}
    format with \code{\link{read.spectrum}} or generated
    by a ZM or fZM model with the \code{\link{EVm}} method.}
  \item{m.max}{number of frequency ranks to be shown in plot.  If
    unspecified, it is determined by the shortest spectrum vector in
    \code{spc}.}
  \item{log}{if \code{TRUE}, display frequency spectra as points and
    lines on a logarithmic scale.  If \code{FALSE}, display spectra as
    side-by-side barplot on a linear scale (default).  The latter is
    only useful when \code{m.max} is comparatively small.}
  \item{y.min, y.max}{range of y-axis.  \code{y.max} is automatically
    computed to fit the data in \code{spc}.  \code{y.min} is only used
    when \code{log=TRUE} and defaults to 100.}
  \item{legend}{a vector of character strings or expressions specifying
    the labels to be shown in a legend box.  If \code{legend} is
    missing, no legend box will be displayed.}
  \item{xlab, ylab}{character strings giving labels for the x-axis and
    y-axis}
  \item{pch, lwd, lty}{vectors of plot symbols, line widths, and line
    types (only used if \code{log=TRUE}.  Values are recycled if
    necessary.  See the \code{par} manpage for possible ways of
    specifying these attributes.}
  \item{col}{a vector of colours for the lines (\code{log=TRUE}) or bars
    (\code{log=FALSE}) in the plot.  Values are recycled if necessary.
    Colours are specified as described in the \code{par} manpage.}
}
\references{
  Baayen, R. Harald (2001). \emph{Word Frequency Distributions.} Kluwer,
  Dordrecht.
}
\seealso{
  \code{\link{read.spectrum}}, \code{\link{zm}}, \code{\link{fzm}}, \code{\link{EVm}}
}
\keyword{UCS}
\keyword{hplot}
\keyword{LNRE}

\eof
% --- Source file: man/ucs.library.Rd ---
\name{ucs.library}
\alias{ucs.library}
\title{Load UCS/R Modules}
\description{
  Since the UCS/R functions are imported into the global namespace, they
  are collected in various modules that can be loaded separately on
  demand.  \code{ucs.library} loads a specified module.  When called
  without arguments, it prints a listing of available modules.
}
\usage{
ucs.library(name, all=FALSE, reload=FALSE)
}
\arguments{
  \item{name}{a character string giving the name of a \emph{single}
    UCS/R module to be loaded.  If omitted, a list of all available
    modules is displayed (see below).}
  \item{all}{if \code{TRUE}, all available modules are loaded}
  \item{reload}{if \code{TRUE}, force module to be loaded even if it has
    already been imported (useful when developing UCS/R modules)}
}
\value{
  Calling the \code{ucs.library} function without arguments returns a
  list of all available UCS/R modules as an object of class
  \code{"UCSLibList"}, which prints as a nicely formatted listing
  including one-line descriptions.  Use \code{names(ucs.library())} to
  obtain a plain vector of module names.
}
\details{
  Like the \code{library} and \code{package} functions,
  \code{ucs.library(module)} checks whether the requested module
  has already been loaded by a previous \code{ucs.library} call.
  Set \code{reload=TRUE} in order to skip this test and force
  re-loading a module (especially while developing or debugging module
  code). 
}
\seealso{
  \code{\link{UCS}} for an overview of the UCS/R modules
}
\examples{
print(ucs.library())  # list of available modules

ucs.library("base")   # load and manage UCS data sets
ucs.library("plots")  # evaluation graphs

ucs.library(all=TRUE) # load all modules
}
\keyword{UCS}
\keyword{utilities}

\eof
% --- Source file: man/ucs.par.Rd ---
\name{ucs.par}
\alias{ucs.par}
\alias{.ucs.PAR}
\title{Graphics Parameters for Evaluation Graphs (plots)}
\description{
  Set default graphics parameters for the \code{evaluation.plot}
  function, similar to \code{par} for general graphics parameters.
  The current parameter values are queried by giving their names as
  character strings.  The values can be set by specifying them as
  arguments in \code{name=value} form, or by passing a single list of
  named values.
}
\usage{
ucs.par(...)

.ucs.PAR
}
\arguments{
  \item{...}{either character strings (or vectors) specifying the names
    of parameters to be queried, or parameters to be set in
    \code{name=value} form, or a single list of named values.  Valid
    parameter names are described below.}
}
\value{
  When parameters are set, their former values are returned in an
  invisible named list.  Such a list can be passed as a single argument
  to \code{ucs.par} to restore the parameter values.

  When a single parameter is queried, its value is returned directly.
  When two or more parameters are queried, the result is a named list.

  Note the inconsistency, which is the same as for \code{par}: setting
  one parameter returns a list, but querying one parameter returns a
  vector (or a scalar, i.e. a vector of length 1).
}
\details{
  The current default parameters are stored in the global variable
  \code{.ucs.PAR}.  They can be queried by giving their names as
  one or more character vectors to \code{ucs.par}.  \code{ucs.par()} (no
  arguments) returns all UCS graphics parameters.

  Parameters are set by specifying their names and the new values as
  \code{name=value} pairs.  Such a list can also be passed as a single
  argument to \code{ucs.par}, which is typically used to restore previous
  parameter values (that have been saved in a list variable).

  In order to restore the "factory settings", reload the module with the
  command \code{ucs.library("plots", reload=TRUE)}.
}
\section{UCS Graphics Parameters}{
  \describe{
    \item{\code{col}}{A character or integer vector specifying line
      colours for up to 10 evaluation graphs (see the \code{par} manpage
      for details). Values are recycled if necessary.}
    \item{\code{lty}}{A character or integer vector specifying line
      styles for up to 10 evaluation graphs (see the \code{par} manpage
      for details). Values are recycled if necessary.}
    \item{\code{lwd}}{A numeric vector specifying line widths for up to 10
      evaluation graphs (see the \code{par} manpage for details). Values
      are recycled if necessary.}
    \item{\code{bw.col}}{The line colours used in B/W mode (see the
      \code{\link{evaluation.plot}} manpage for details).}
    \item{\code{bw.lty}}{The line styles used in B/W mode.}
    \item{\code{bw.lwd}}{The line widths in B/W mode.}
    \item{\code{n.first}}{The smallest n-best list to be evaluated (default:
      100).  Shorter n-best lists typically lead to highly unstable
      evaluation graphs.  It may be necessary to set \code{n.first} to a
      higher value for evaluation based on random samples (cf.
      \code{\link{evaluation.plot}}).}
    \item{\code{n.step}}{The step width for n-best lists in evaluation
      graphs (default: 1).  The default setting evaluates all possible
      n-best lists.  Higher values speed up computation, make graphs
      look less jagged, and reduce the size of PostScript files.  A
      useful range is \eqn{5 \ldots 20}, depending on the size of the
      data set file.}
    \item{\code{test.step}}{Step width for n-best lists where
      significance tests for result differences are applied, as a
      multiple of \code{n.step} (default: 10).  Since these tests are
      time-consuming and significant differences are indicated by
      fairly large symbols in the plot, values below 5 are rarely useful.} 
    \item{\code{cex}}{A character expansion factor for labels,
      annotations, and symbols in evaluation plots (see \code{par} for
      details).}
    \item{\code{lex}}{This parameter can be used to increase the line
      widths of evaluation graphs and some decorations.  Not that
      \code{lex} is not an expansion factor, but is simply \emph{added}
      to all line widths in the plot.}
    \item{\code{do.file}}{If \code{FALSE}, \code{\link{evaluation.file}}
      will not generate PostScript files, which is useful while testing
      and fine-tuning plots (default: \code{TRUE}).}
    }
}
\seealso{
  \code{\link{evaluation.plot}}, \code{\link{evaluation.file}}, \code{par}
}
\examples{
print(names(ucs.par()))         # list available parameters

ucs.par("col", "lty", "lwd")    # the default line styles
ucs.par(c("col", "lty", "lwd")) # works as well

## temporary changes to graphics paramters:
par.save <- ucs.par(n.first=200, n.step=5)
## plots use the modified parameters here
ucs.par(par.save)		# restore previous values

ucs.library("plots", reload=TRUE) # reload module for factory defaults 
}
\keyword{UCS}
\keyword{iplot}

\eof
% --- Source file: man/write.lexstats.Rd ---
\name{write.lexstats}
\alias{write.lexstats}
\alias{write.lexstats.zm}
\alias{write.lexstats.fzm}
\title{Write Data Files for Goodness-of-Fit Evaluation of LNRE Model (zm, fzm)}
\description{
  Creates three data files in \code{lexstats} format, which can be used
  to compare and LNRE model with other models from the \code{lexstats}
  package and evaluate its goodness-of-fit by a multivariate
  chi-squared test (Baayen, 2001, Sec. 3.3), using the \code{lnreChi2}
  program (Baayen, 2001).
}
\usage{
write.lexstats(model, file)
}
\arguments{
  \item{model}{an object of class \code{"zm"} or \code{"fzm"},
    representing a Zipf-Mandelbrot (ZM) or finite Zipf-Mandelbrot (fZM)
    LNRE model.  The object must include observed word frequency data
    (in components \code{N}, \code{V}, and \code{spc}), usually
    because the model parameters have been estimated from the observed
    frequency spectrum.}
  \item{file}{a character string giving the basename of the files that
    will be created}
}
\value{
  The full basename of the created files (obtained by adding a
  model-specific suffix to the \code{file} parameter).
}
\details{
  This functions creates files in \code{lexstats} format with the
  extensions \code{.spc}, \code{.sp2}, and \code{.ev2}, which are
  required by the \code{lnreChi2} tool (Baayen, 2001, 270).

  In addition, the basename \code{file} is extended with the string
  \code{"_bZM"} (for a ZM model) or \code{"_bfZM"} (for a fZM model),
  so that the \code{lnreChi2} tool can correctly identify the number of
  degrees of freedom (reduced by two estimated parameters for the ZM
  model, and three estimated parameters for the fZM model).
}
\note{
  The combination of \code{write.lexstats} and the external
  \code{lnreChi2} program to evaluate the goodness-of-fit of a LNRE
  model has been
  superseded by the built-in \code{\link{lnre.goodness.of.fit}}
  function (in the \code{lexstats} module).  This function implements
  the multivariate chi-squared test as described by Baayen (2001,
  Sec. 3.3) in \R without relying on external software.
}
\references{
  Baayen, R. Harald (2001). \emph{Word Frequency Distributions.} Kluwer,
  Dordrecht.
}
\seealso{
  \code{\link{zm}}, \code{\link{fzm}}, \code{\link{EV}},
  \code{\link{EVm}}, \code{\link{lnre.goodness.of.fit}}
}
\keyword{UCS}
\keyword{models}
\keyword{LNRE}

\eof
% --- Source file: man/zm.Rd ---
\name{zm}
\alias{zm}
\title{The Zipf-Mandelbrot LNRE Model (zm)}
\description{
  Object constructor for a Zipf-Mandelbrot (ZM) LNRE model with
  parameters \eqn{\alpha} and \eqn{C} (Evert, 2004a).
  Either the parameters are specified explicitly, or one or both of them
  can be estimated from an observed frequency spectrum.
}
\synopsis{
zm(alpha=NULL, C=NULL, N=NULL, V=NULL, spc=NULL, m.max=15, stepmax=10, debug=FALSE)
}
\usage{
zm(alpha, C)

zm(alpha, N, V)

zm(N, V, spc, m.max=15, stepmax=10, debug=FALSE)
}
\arguments{
  \item{alpha}{a number in the range \eqn{(0,1)}, the shape parameter
    \eqn{\alpha} of the ZM model.  \code{alpha} can automatically be
    estimated from \code{N}, \code{V}, and \code{spc}.}
  \item{C}{a positive number, the parameter \eqn{C} of the ZM model.
    \code{C} can automatically be estimated from \code{N} and \code{V}.}
  \item{N}{the sample size, i.e. number of observed tokens}
  \item{V}{the vocabulary size, i.e. the number of observed types}
  \item{spc}{a vector of non-negative integers representing the class
    sizes \eqn{V_m} of the observed frequency spectrum.  The vector is
    usually read from a file in \code{lexstats} format with the
    \code{\link{read.spectrum}} function.}
  \item{m.max}{the number of ranks from \code{spc} that will be used to
    estimate the \eqn{\alpha} parameter}
  \item{stepmax}{maximal step size of the \code{nlm} function used for
    parameter estimation.  It should not be necessary to change the
    default value.}
  \item{debug}{if \code{TRUE}, print debugging information during the
    parameter estimation process.  This feature can be useful to find
    out why parameter estimation fails.}
}
\value{
  An object of class \code{"zm"} with the following components:
  \item{alpha}{value of the \eqn{\alpha} parameter}
  \item{B}{value of the upper bound \eqn{B} (a normalisation device)}
  \item{C}{value of the \eqn{C} parameter}
  \item{N}{number of observed tokens (if specified)}
  \item{V}{number of observed types (if specified)}
  \item{spc}{observed frequency spectrum (if specified)}
  This object \code{print}s a short summary, including a comparison
  of the first ranks of the observed and expected frequency spectrum (if
  available).
}
\details{
  The ZM model with parameters \eqn{\alpha \in (0,1)} and \eqn{C > 0} is
  defined by the type density function
  \deqn{g(\pi) := C\cdot \pi^{-\alpha-1}}{%
    g(p) := C * p^(-alpha - 1)}
  for \eqn{0\leq \pi\leq B}{0 <= p <= B}, where the upper bound \eqn{B}
  is determined from \eqn{C} by the normalisation condition
  \deqn{\int_0^{\infty} \pi\cdot g(\pi) d\pi = 1}{%
    integral_0^Inf p * g(p) dp = 1}

  The parameter \eqn{\alpha} is estimated by nonlinear minimisation
  (\code{nlm}) of a multinomial chi-squared statistic
  for the observed against the expected frequency spectrum.  Note that
  this is different from the multivariate chi-squared test used to
  measure the goodness-of-fit of the final model (Baayen, 2001,
  Sec. 3.3).

  See Evert (2004, Ch. 4) for further mathematical details, especially
  concerning the expected vocabulary size, frequency spectrum and
  conditional parameter distribution, as well as their variances.
}
\references{
  Baayen, R. Harald (2001). \emph{Word Frequency Distributions.} Kluwer,
  Dordrecht.

  Evert, Stefan (2004). \emph{The Statistics of Word Cooccurrences: Word
    Pairs and Collocations.} PhD Thesis, IMS, University of Stuttgart.

  Evert, Stefan (2004a). A simple LNRE model for random character
  sequences. In \emph{Proceedings of JADT 2004}, Louvain-la-Neuve,
  Belgium, pages 411--422.
}
\seealso{
  \code{\link{fzm}}, \code{\link{EV}}, \code{\link{EVm}},
  \code{\link{VV}}, \code{\link{VVm}},
  \code{\link{write.lexstats}}, \code{\link{lnre.goodness.of.fit}},
  \code{\link{read.spectrum}}, and \code{\link{spectrum.plot}}
}
\keyword{UCS}
\keyword{models}
\keyword{LNRE}

\eof
