# -*-cperl-*-
## Filename: nsp2ucs.perl
## Modified: Sun May  8 20:09:34 2005 (evert)   
##   Author: Stefan Evert
##  Purpose: import data set from Ngram Statistics Package
$| = 1;

use UCS;
use UCS::File;
use UCS::DS::Stream;

use Getopt::Long;
use locale;

$Verbose = 0;					# -v = verbose mode
$Help = 0;					# -h = help page

$ok = GetOptions(
		 "verbose|v" => \$Verbose,
		 "help|h" => \$Help,
		 );

die 
  "\nUsage:  ucs-tool nsp2ucs [-v] <input.cnt> <output.ds>\n\n",
  "Reads data set <input.cnt> in NSP format [ http://ngram.sourceforge.net ]\n",
  "and converts it to UCS data set file <output.ds>.\n",
  "Only bigram data will be accepted, of course.\n",
  unless $ok and (not $Help) and @ARGV == 2;

($cntfile, $dsfile) = @ARGV;

$fh = UCS::File::Open $cntfile;
print "Input file:    $cntfile\n"
  if $Verbose;

chomp($N = <$fh>);
die "Format error in $cntfile [line #1: $N]\n"
  unless $N =~ /^[0-9]+$/ and $N > 0;
print "Sample size:   N = $N\n"
  if $Verbose;

($l1, $l2, @fdata) = get_line_nsp($fh);
die "Sorry, I can only import bigram data from NSP.\n"
  unless @fdata == 3;

$size = 0;
while (1) {					# check size and format of NSP file
  die "Format error in $cntfile [line #$.]\n"
    unless @fdata == 3 
      and $fdata[0] <= $fdata[1] and $fdata[0] <= $fdata[2] and $fdata[1] <= $N and $fdata[2] <= $N;
  $size++;
  last
    unless ($l1, $l2, @fdata) = get_line_nsp($fh);
}
$fh->close;
print "Data set size: $size rows\n"
  if $Verbose;

$fh = UCS::File::Open $cntfile;			# re-open NSP file and skip first line
chomp($N = <$fh>);

$ds = new UCS::DS::Stream::Write $dsfile;
$ds->add_vars(qw<id l1 l2 f f1 f2 N>);
$ds->add_comments("Imported with nsp2ucs.perl from NSP file $cntfile");
$ds->set_global("size", $size);
$ds->open;

($l1, $l2, $f, $f1, $f2) = get_line_nsp($fh);
$id = 0;
while (1) {
  $id++;
  $ds->data("id" => $id, "l1" => $l1, "l2" => $l2,
	    "f" => $f, "f1" => $f1, "f2" => $f2, "N" => $N);
  $ds->write;
  last
    unless ($l1, $l2, $f, $f1, $f2) = get_line_nsp($fh);
}
$ds->close;
$fh->close;

print "Output file:   $dsfile\n"
  if $Verbose;



# ($l1, $l2, $f, $f1, $f2) = get_line_nsp($fh);
sub get_line_nsp {
  my $fh = shift;
  my $line = <$fh>;
  return ()
    unless $line;
  chomp $line;
  my ($l1, $l2, $fdata, $dummy) = split /<>/, $line;
  die "Format error in $cntfile [line #$.: $line]\n"
    unless defined $fdata and not defined $dummy;
  my @freqs = split " ", $fdata;
  return ($l1, $l2, @freqs);
}
