# -*-cperl-*-
## Filename: make-dummy-ds.perl
## Modified: Sun May  8 20:11:02 2005 (evert)   
##   Author: Stefan Evert
##  Purpose: make 'dummy' data set for empirical studies of the mathematical behaviour of AMs
$| = 1;

use UCS;
use UCS::DS::Stream;



die "\nUsage:  ucs-tool make-dummy-ds <dummy.ds> <k> [<k.marginal>]\n\n",
  "Creates a dummy data set where the joint and marginal frequencies of pair types\n",
  "vary systematically across ten values within each order of magnitude.  <k> gives\n",
  "the sample size in orders of magnitude (i.e. N = 10^k), and <k.marginal> specifies\n",
  "how many orders of magnitude are covered by the marginal frequencies.  It defaults\n",
  "to k/2, rounded up to the nearest integer.\n",
  unless @ARGV == 2 or @ARGV == 3;

$filename = shift @ARGV;
$K = shift @ARGV;
$Km = (@ARGV) ? shift @ARGV : int(($K + 1) / 2);

$N = 10 ** $K;					# sample size

# open data set file and write header
$ds = new UCS::DS::Stream::Write $filename;
$ds->add_comments("Dummy data set file with frequency signatures varying systematically.",
		  "Sample size = 10^$K, marginal frequencies cover $Km orders of magnitude");
$ds->add_vars(qw<id l1 l2 f f1 f2 N>);
$ds->open;

$id = 0;
foreach $k1 (1 .. $Km) {			# order of magnitude, first component
  $F1 = 10 ** ($k1-1);			        # base frequency for this block
  foreach $k2 (1 .. $Km) {			# order of magnitude, second component
    $F2 = 10 ** ($k2-1);			# base frequency for this block
    $s1 = sprintf "(%d:%d", $F1, $F1*9;
    $s2 = sprintf "%d:%d)", $F2, $F2*9;
    printf "%12s, %-12s ", $s1, $s2;
    foreach $r1 (1 .. 9) {			# marginal freq. relative to base (first comp.)
      $f1 = $F1 * $r1;
      foreach $r2 (1 .. 9) {			# marginal freq. relative to base (second comp.)
	$f2 = $F2 * $r2;
	$f_max = ($f1 <= $f2) ? $f1 : $f2;	# max. possible value for joint frequency
      INNER:
	foreach $k (1 .. $Km) {		        # order of magnitude, joint frequency
	  $F = 10 ** ($k-1);			# base joint frequency for this block
	  foreach $r (1 .. 9) {			# joint freq. relative to base
	    $f = $F * $r;
	    last INNER if $f > $f_max;
	    $l1 = "${r}e$F";
	    $l2 = "${r1}e$F1:${r2}e$F2";
	    $ds->columns(++$id, $l1, $l2, $f, $f1, $f2, $N);
	    $ds->write;
	  }
	}
      }
    }
  }
  print "\n";
}
$ds->close;

print "Data set size = $id pair types.\n";
