# -*-cperl-*-
###################################################################
###                                                             ###
###    Author: Stefan Evert                                     ###
###   Purpose: Prepare data sets for UCS/R tutorial.            ###
###   Created: Tue Jun 29 15:23:58 2004                         ###
###  Modified: Sun May  8 20:11:19 2005 (evert)                 ###
###                                                             ###
###################################################################
$| = 1;

use UCS;
use UCS::R;
use UCS::AM;
use UCS::DS::Memory;

use Getopt::Long;

$Opt_NoPV = 0;
$Opt_Help = 0;

$ok = GetOptions(
		 "no-pv|n" => \$Opt_NoPV,
		 "help|h" => \$Opt_Help,
		 );

die "Usage:  ucs-tool prepare-tutorial [--no-pv]\n"
  if $Opt_Help or not $ok;

$rawfile = "Distrib/glaw.ds.gz";
$datadir = "$UCS::BaseDir/DataSet";
$annotfile = "glaw.scores.ds.gz";
$annotpath = "$datadir/$annotfile";

@AM = UCS::AM_Keys();
if ($Opt_NoPV) {
  @AM = grep {not /\.pv$/} @AM;
}
print "AM = @AM\n";

print "Loading $rawfile ... ";
$ds = new UCS::DS::Memory $rawfile;
$ds_N = $ds->size;
print "$ds_N rows\n";

if (-f $annotpath) {
  print "Data set $annotfile exists, checking ... ";
  $ds2 = eval { new UCS::DS::Memory $annotpath };
  if (defined $ds2) {
    $ds2_N = $ds2->size;
    if ($ds2_N != $ds_N) {
      print "wrong size ($ds2_N rows)\n";
    }
    elsif (grep {not $ds2->var($_)} @UCS::CoreVars) {
      print "core variables incomplete\n"
    }
    elsif (grep {not $ds2->var("am.$_")} @AM) {
      print "missing association scores\n";
    }
    else {
      print "ok\n";
      print "Done.\n";
      exit 0;
    }
  }
  else {
    print "file is corrupt\n";
  }
  print "Rebuilding $annotfile from $rawfile ...\n";
}

if (not $Opt_NoPV) {		 # --no-pv => try to avoid using the R backend
  print "Starting R backend ... ";
  UCS::R::Start();
  print "ok\n";
}

print "Annotating association scores ";
foreach $am (@AM) {
  print ".";
  $exp = UCS::AM_Expression($am);
  $ds->eval("am.$am", $exp);
}
print " ok\n";

print "Writing data set file ... ";
$ds->save($annotpath);
print "ok\n";

print "[$annotpath]\n";
print "Done.\n";
